@@ -39,10 +39,10 @@ import org.kie.workbench.common.forms.adf.definitions.annotations.i18n.I18nSetti
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
-import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
+import org.kie.workbench.common.stunner.core.definition.property.PropertyMetaTypes;
+import org.kie.workbench.common.stunner.core.graph.content.HasContentDefinitionId;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
@@ -50,19 +50,25 @@ import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.pr
 
 @Portable
 @Bindable
-@Definition(graphFactory = NodeFactory.class, nameField = "text")
+@Definition()
 @FormDefinition(policy = FieldPolicy.ONLY_MARKED,
         defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)},
         i18n = @I18nSettings(keyPreffix = "org.kie.workbench.common.dmn.api.definition.model.TextAnnotation"),
         startElement = "id")
 public class TextAnnotation extends Artifact implements DMNViewDefinition<GeneralRectangleDimensionsSet>,
                                                         HasText,
+                                                        HasContentDefinitionId,
                                                         DynamicReadOnly {
 
     private static final String[] READONLY_FIELDS = {"Description", "Text", "TextFormat"};
 
     protected boolean allowOnlyVisualChange;
 
+    /**
+     * Hold the {@link DMNDiagramElement} id for the {@link TextAnnotation} instance.
+     */
+    private String dmnDiagramId;
+
     @Category
     private static final String stunnerCategory = Categories.NODES;
 
@@ -71,7 +77,7 @@ public class TextAnnotation extends Artifact implements DMNViewDefinition<Genera
             .add("text-annotation")
             .build();
 
-    @Property
+    @Property(meta = PropertyMetaTypes.NAME)
     @FormField(afterElement = "description")
     protected Text text;
 
@@ -79,16 +85,16 @@ public class TextAnnotation extends Artifact implements DMNViewDefinition<Genera
     @FormField(afterElement = "text", labelKey = "text")
     protected TextFormat textFormat;
 
-    @PropertySet
+    @Property
     @FormField(afterElement = "variable")
     @Valid
     protected BackgroundSet backgroundSet;
 
-    @PropertySet
+    @Property
     @FormField(afterElement = "backgroundSet")
     protected FontSet fontSet;
 
-    @PropertySet
+    @Property
     protected GeneralRectangleDimensionsSet dimensionsSet;
 
     public TextAnnotation() {
@@ -178,6 +184,26 @@ public class TextAnnotation extends Artifact implements DMNViewDefinition<Genera
         this.textFormat = textFormat;
     }
 
+    @Override
+    public String getContentDefinitionId() {
+        return getId().getValue();
+    }
+
+    @Override
+    public String getDiagramId() {
+        return dmnDiagramId;
+    }
+
+    @Override
+    public void setContentDefinitionId(final String contentDefinitionId) {
+        setId(new Id(contentDefinitionId));
+    }
+
+    @Override
+    public void setDiagramId(final String dmnDiagramId) {
+        this.dmnDiagramId = dmnDiagramId;
+    }
+
     @Override
     public boolean equals(final Object o) {
         if (this == o) {
