@@ -28,19 +28,27 @@ import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
 
+import elemental2.dom.Element;
 import elemental2.dom.HTMLElement;
+import elemental2.dom.NodeList;
 import org.kie.workbench.common.dmn.api.definition.model.ConstraintType;
+import org.kie.workbench.common.dmn.client.editors.expressions.util.NameUtils;
 import org.kie.workbench.common.dmn.client.editors.types.DataTypeChangedEvent;
 import org.kie.workbench.common.dmn.client.editors.types.common.DataType;
 import org.kie.workbench.common.dmn.client.editors.types.common.DataTypeManager;
+import org.kie.workbench.common.dmn.client.editors.types.common.ScrollHelper;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTypeEditModeToggleEvent;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.SmallSwitchComponent;
 import org.kie.workbench.common.dmn.client.editors.types.listview.confirmation.DataTypeConfirmation;
 import org.kie.workbench.common.dmn.client.editors.types.listview.constraint.DataTypeConstraint;
+import org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListComponent;
 import org.kie.workbench.common.dmn.client.editors.types.listview.validation.DataTypeNameFormatValidator;
+import org.kie.workbench.common.dmn.client.editors.types.shortcuts.DataTypeShortcuts;
 import org.uberfire.client.mvp.UberElemental;
+import org.uberfire.client.views.pfly.selectpicker.ElementHelper;
 import org.uberfire.mvp.Command;
 
+import static java.util.Collections.emptyList;
 import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.BOOLEAN;
 import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.CONTEXT;
 import static org.kie.workbench.common.dmn.client.editors.types.persistence.CreationType.ABOVE;
@@ -87,6 +95,12 @@ public class DataTypeListItem {
 
     private String[] canNotHaveConstraintTypes;
 
+    private HTMLElement dragAndDropElement;
+
+    private final DataTypeShortcuts dataTypeShortcuts;
+
+    private final ScrollHelper scrollHelper;
+
     @Inject
     public DataTypeListItem(final View view,
                             final DataTypeSelect dataTypeSelectComponent,
@@ -96,7 +110,9 @@ public class DataTypeListItem {
                             final DataTypeConfirmation confirmation,
                             final DataTypeNameFormatValidator nameFormatValidator,
                             final Event<DataTypeEditModeToggleEvent> editModeToggleEvent,
-                            final Event<DataTypeChangedEvent> dataTypeChangedEvent) {
+                            final Event<DataTypeChangedEvent> dataTypeChangedEvent,
+                            final DataTypeShortcuts dataTypeShortcuts,
+                            final ScrollHelper scrollHelper) {
         this.view = view;
         this.dataTypeSelectComponent = dataTypeSelectComponent;
         this.dataTypeConstraintComponent = dataTypeConstraintComponent;
@@ -106,6 +122,8 @@ public class DataTypeListItem {
         this.nameFormatValidator = nameFormatValidator;
         this.editModeToggleEvent = editModeToggleEvent;
         this.dataTypeChangedEvent = dataTypeChangedEvent;
+        this.dataTypeShortcuts = dataTypeShortcuts;
+        this.scrollHelper = scrollHelper;
         this.dataTypeListComponent.setOnValueChanged(value -> refreshConstraintComponent());
     }
 
@@ -123,22 +141,24 @@ public class DataTypeListItem {
         this.dataTypeList = dataTypeList;
     }
 
-    public HTMLElement getElement() {
-        return view.getElement();
-    }
-
     void setupDataType(final DataType dataType,
                        final int level) {
 
         this.dataType = dataType;
         this.level = level;
 
+        setupDragAndDropComponent();
         setupSelectComponent();
         setupListComponent();
         setupConstraintComponent();
         setupView();
     }
 
+    void setupDragAndDropComponent() {
+        final DNDListComponent dragAndDropComponent = getDNDListComponent();
+        this.dragAndDropElement = dragAndDropComponent.registerNewItem(getContentElement());
+    }
+
     void setupListComponent() {
         dataTypeListComponent.setValue(getDataType().isList());
         refreshListYesLabel();
@@ -154,10 +174,14 @@ public class DataTypeListItem {
     }
 
     void setupView() {
+
         view.setupSelectComponent(dataTypeSelectComponent);
         view.setupConstraintComponent(dataTypeConstraintComponent);
         view.setupListComponent(dataTypeListComponent);
         view.setDataType(getDataType());
+
+        setupIndentationLevel();
+        hideTooltips();
     }
 
     void refresh() {
@@ -167,6 +191,21 @@ public class DataTypeListItem {
         view.setName(getDataType().getName());
         setupListComponent();
         setupConstraintComponent();
+        hideTooltips();
+    }
+
+    void cleanSubDataTypes() {
+        refreshDataTypeList(emptyList());
+    }
+
+    void refreshSubDataTypes() {
+        refreshDataTypeList(getDataType().getSubDataTypes());
+        view.enableFocusMode();
+    }
+
+    private void refreshDataTypeList(final List<DataType> subDataTypes) {
+        dataTypeList.refreshSubItemsFromListItem(this, subDataTypes);
+        dataTypeList.refreshDragAndDropList();
     }
 
     public DataType getDataType() {
@@ -181,32 +220,30 @@ public class DataTypeListItem {
         return level;
     }
 
-    public String[] getCanNotHaveConstraintTypes() {
+    private String[] getCanNotHaveConstraintTypes() {
         return canNotHaveConstraintTypes;
     }
 
     void expandOrCollapseSubTypes() {
-        if (view.isCollapsed()) {
+        if (isCollapsed()) {
             expand();
         } else {
             collapse();
         }
     }
 
+    public boolean isCollapsed() {
+        return view.isCollapsed();
+    }
+
     public void expand() {
         view.expand();
+        dataTypeList.highlightLevel(getDragAndDropElement());
     }
 
     public void collapse() {
         view.collapse();
-    }
-
-    void refreshSubItems(final List<DataType> dataTypes) {
-
-        dataTypeList.refreshSubItemsFromListItem(this, dataTypes);
-
-        view.enableFocusMode();
-        view.toggleArrow(!dataTypes.isEmpty());
+        dataTypeList.highlightLevel(getDragAndDropElement());
     }
 
     public void enableEditMode() {
@@ -224,7 +261,6 @@ public class DataTypeListItem {
         view.showSaveButton();
         view.showDataTypeNameInput();
         view.showListContainer();
-        view.hideKebabMenu();
         view.hideListYesLabel();
         view.enableFocusMode();
 
@@ -232,12 +268,22 @@ public class DataTypeListItem {
         dataTypeConstraintComponent.enableEditMode();
 
         editModeToggleEvent.fire(new DataTypeEditModeToggleEvent(true, this));
+        dataTypeList.fireOnDataTypeListItemUpdateCallback(this);
     }
 
     public void disableEditMode() {
         if (view.isOnFocusMode()) {
             discardNewDataType();
             closeEditMode();
+            hideTooltips();
+        }
+    }
+
+    void hideTooltips() {
+        final String selector = ".tooltip";
+        final NodeList<Element> tooltips = getDataTypeList().getListItems().querySelectorAll(selector);
+        for (int i = 0; i < tooltips.length; i++) {
+            ElementHelper.remove(tooltips.getAt(i));
         }
     }
 
@@ -291,7 +337,6 @@ public class DataTypeListItem {
     List<DataType> persist(final DataType dataType) {
         return dataTypeManager
                 .from(dataType)
-                .withSubDataTypes(dataTypeSelectComponent.getSubDataTypes())
                 .get()
                 .update();
     }
@@ -305,7 +350,8 @@ public class DataTypeListItem {
         setupListComponent();
         setupSelectComponent();
         setupConstraintComponent();
-        refreshSubItems(oldDataType.getSubDataTypes());
+        setupIndentationLevel();
+        refreshSubDataTypes();
     }
 
     DataType discardDataTypeProperties() {
@@ -324,7 +370,6 @@ public class DataTypeListItem {
         view.hideDataTypeNameInput();
         view.hideListContainer();
         view.showEditButton();
-        view.showKebabMenu();
         view.disableFocusMode();
 
         refreshListYesLabel();
@@ -344,23 +389,42 @@ public class DataTypeListItem {
     }
 
     public void remove() {
-        confirmation.ifIsNotReferencedDataType(getDataType(), doRemove());
+        confirmation.ifIsNotReferencedDataType(getDataType(), removeItem());
     }
 
-    Command doRemove() {
+    public Command removeItem() {
         return () -> {
-
-            final List<DataType> destroyedDataTypes = getDataType().destroy();
-            final List<DataType> removedDataTypes = removeTopLevelDataTypes(destroyedDataTypes);
-
-            destroyedDataTypes.removeAll(removedDataTypes);
-
-            dataTypeList.refreshItemsByUpdatedDataTypes(destroyedDataTypes);
-
-            fireDataChangedEvent();
+            dataTypeList.disableEditModeForChildren(this);
+            destroyWithDependentTypes();
         };
     }
 
+    public Command destroy() {
+        return this::destroyWithDependentTypes;
+    }
+
+    public void destroyWithDependentTypes() {
+        final List<DataType> destroyedDataTypes = getDataType().destroy();
+        destroy(destroyedDataTypes, true);
+    }
+
+    public void destroyWithoutDependentTypes() {
+        final List<DataType> destroyedDataTypes = getDataType().destroyWithoutDependentTypes();
+        destroy(destroyedDataTypes, false);
+    }
+
+    void destroy(final List<DataType> destroyedDataTypes, final boolean fireDataChangedEvent) {
+
+        final List<DataType> removedDataTypes = removeTopLevelDataTypes(destroyedDataTypes);
+        destroyedDataTypes.removeAll(removedDataTypes);
+        dataTypeList.refreshItemsByUpdatedDataTypes(destroyedDataTypes);
+
+        if (fireDataChangedEvent) {
+            fireDataChangedEvent();
+        }
+        hideTooltips();
+    }
+
     List<DataType> removeTopLevelDataTypes(final List<DataType> destroyedDataTypes) {
         return destroyedDataTypes.stream()
                 .filter(dataType -> dataType.isTopLevel() && (isDestroyedDataType(dataType) || isAReferenceToDestroyedDataType(dataType)))
@@ -379,7 +443,7 @@ public class DataTypeListItem {
     DataType updateProperties(final DataType dataType) {
         return dataTypeManager
                 .from(dataType)
-                .withName(getName())
+                .withName(NameUtils.normaliseName(getName()))
                 .withType(getType())
                 .withConstraint(getConstraint())
                 .withConstraintType(getConstraintType())
@@ -443,16 +507,25 @@ public class DataTypeListItem {
         closeEditMode();
 
         final DataType newDataType = newDataType();
-        final String referenceDataTypeHash = dataTypeList.calculateParentHash(getDataType());
-        final List<DataType> updatedDataTypes = newDataType.create(getDataType(), ABOVE);
+        final String referenceDataTypeHash = insertFieldAbove(newDataType);
 
-        if (newDataType.isTopLevel()) {
-            dataTypeList.insertAbove(newDataType, getDataType());
+        enableEditModeAndUpdateCallbacks(getNewDataTypeHash(newDataType, referenceDataTypeHash));
+    }
+
+    public String insertFieldAbove(final DataType dataType) {
+
+        final String referenceDataTypeHash = dataTypeList.calculateParentHash(getDataType());
+        final List<DataType> updatedDataTypes = dataType.create(getDataType(), ABOVE);
+
+        if (dataType.isTopLevel()) {
+            dataTypeList.insertAbove(dataType, getDataType());
         } else {
             dataTypeList.refreshItemsByUpdatedDataTypes(updatedDataTypes);
         }
 
-        enableEditModeAndUpdateCallbacks(getNewDataTypeHash(newDataType, referenceDataTypeHash));
+        getDNDListComponent().refreshItemsCSSAndHTMLPosition();
+
+        return referenceDataTypeHash;
     }
 
     public void insertFieldBelow() {
@@ -460,29 +533,57 @@ public class DataTypeListItem {
         closeEditMode();
 
         final DataType newDataType = newDataType();
-        final String referenceDataTypeHash = dataTypeList.calculateParentHash(getDataType());
-        final List<DataType> updatedDataTypes = newDataType.create(getDataType(), BELOW);
-
-        if (newDataType.isTopLevel()) {
-            dataTypeList.insertBelow(newDataType, getDataType());
-        } else {
-            dataTypeList.refreshItemsByUpdatedDataTypes(updatedDataTypes);
-        }
+        final String referenceDataTypeHash = insertFieldBelow(newDataType);
 
         enableEditModeAndUpdateCallbacks(getNewDataTypeHash(newDataType, referenceDataTypeHash));
     }
 
+    public String insertFieldBelow(final DataType dataType) {
+
+        final String referenceDataTypeHash = dataTypeList.calculateParentHash(getDataType());
+        final List<DataType> updatedDataTypes = dataType.create(getDataType(), BELOW);
+
+        if (dataType.isTopLevel()) {
+            dataTypeList.insertBelow(dataType, getDataType());
+        } else {
+            dataTypeList.refreshItemsByUpdatedDataTypes(updatedDataTypes);
+        }
+
+        getDNDListComponent().refreshItemsCSSAndHTMLPosition();
+
+        return referenceDataTypeHash;
+    }
+
     public void insertNestedField() {
 
+        final DataType newDataType = newDataType();
+        final String referenceDataTypeHash = dataTypeList.calculateHash(getDataType());
+
+        insertNestedField(newDataType);
+
+        enableEditModeAndUpdateCallbacks(getNewDataTypeHash(newDataType, referenceDataTypeHash));
+    }
+
+    public void insertNestedField(final DataType newDataType) {
+
+        final String referenceDataTypeHash = dataTypeList.calculateHash(getDataType());
+
         closeEditMode();
         expand();
 
-        final DataType newDataType = newDataType();
-        final String referenceDataTypeHash = dataTypeList.calculateHash(getDataType());
         final List<DataType> updatedDataTypes = newDataType.create(getDataType(), NESTED);
-        dataTypeList.refreshItemsByUpdatedDataTypes(updatedDataTypes);
 
-        enableEditModeAndUpdateCallbacks(getNewDataTypeHash(newDataType, referenceDataTypeHash));
+        refreshItemsByUpdatedDataTypes(updatedDataTypes);
+        expandAndHighlight(referenceDataTypeHash);
+    }
+
+    private void refreshItemsByUpdatedDataTypes(final List<DataType> updatedDataTypes) {
+        dataTypeList.refreshItemsByUpdatedDataTypes(updatedDataTypes.stream().distinct().collect(Collectors.toList()));
+    }
+
+    private void expandAndHighlight(final String dataTypeHash) {
+        final Optional<DataTypeListItem> dataTypeListItem = dataTypeList.findItemByDataTypeHash(dataTypeHash);
+        dataTypeListItem.ifPresent(DataTypeListItem::expand);
     }
 
     void enableEditModeAndUpdateCallbacks(final String dataTypeHash) {
@@ -515,18 +616,11 @@ public class DataTypeListItem {
             return true;
         }
 
-        if (Stream.of(getCanNotHaveConstraintTypes())
-                .filter(type -> Objects.equals(type, getType()))
-                .findFirst()
-                .isPresent()) {
+        if (Stream.of(getCanNotHaveConstraintTypes()).anyMatch(type -> Objects.equals(type, getType()))) {
             return true;
         }
 
-        if (isIndirectCanNotHaveConstraintType()) {
-            return true;
-        }
-
-        return false;
+        return isIndirectCanNotHaveConstraintType();
     }
 
     boolean isStructureType() {
@@ -546,12 +640,70 @@ public class DataTypeListItem {
 
         if (customType.isPresent()) {
             final String type = customType.get().getType();
-            return Arrays.stream(types).anyMatch(t -> t.equals(type)) || isIndirectTypeOf(type, types);
+            return Arrays.asList(types).contains(type) || isIndirectTypeOf(type, types);
         }
 
         return false;
     }
 
+    HTMLElement getContentElement() {
+        return view.getElement();
+    }
+
+    void refreshItemsCSSAndHTMLPosition() {
+        dataTypeList.refreshItemsCSSAndHTMLPosition();
+    }
+
+    HTMLElement getDragAndDropListElement() {
+        return getDNDListComponent().getElement();
+    }
+
+    void setPositionX(final Element element,
+                      final double positionX) {
+        getDNDListComponent().setPositionX(element, positionX);
+    }
+
+    void setPositionY(final Element element,
+                      final double positionY) {
+        getDNDListComponent().setPositionY(element, positionY);
+    }
+
+    int getPositionY(final Element element) {
+        return getDNDListComponent().getPositionY(element);
+    }
+
+    private DNDListComponent getDNDListComponent() {
+        return dataTypeList.getDNDListComponent();
+    }
+
+    public HTMLElement getDragAndDropElement() {
+        return dragAndDropElement;
+    }
+
+    void setupIndentationLevel() {
+        setPositionX(getDragAndDropElement(), getLevel() - 1d);
+    }
+
+    public void highlightLevel(final DataType dataType) {
+        dataTypeList.highlightLevel(dataType);
+    }
+
+    public void enableShortcutsHighlight() {
+        final HTMLElement target = getDragAndDropElement();
+        final HTMLElement container = getDataTypeList().getListItems();
+        scrollHelper.scrollTo(target, container);
+        dataTypeList.highlightLevel(target);
+        dataTypeShortcuts.highlight(target);
+    }
+
+    void addDataTypeRow() {
+        if (isStructureType()) {
+            insertNestedField();
+        } else {
+            insertFieldBelow();
+        }
+    }
+
     public interface View extends UberElemental<DataTypeListItem> {
 
         void setDataType(final DataType dataType);
@@ -595,9 +747,5 @@ public class DataTypeListItem {
         String getName();
 
         void setName(final String name);
-
-        void hideKebabMenu();
-
-        void showKebabMenu();
     }
 }
