@@ -19,43 +19,41 @@ package org.kie.workbench.common.dmn.client.canvas.controls.toolbox;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.Optional;
-import java.util.function.Consumer;
 
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
+import org.kie.workbench.common.stunner.core.client.ManagedInstanceStub;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.components.toolbox.Toolbox;
 import org.kie.workbench.common.stunner.core.client.components.toolbox.actions.ActionsToolbox;
 import org.kie.workbench.common.stunner.core.client.components.toolbox.actions.ActionsToolboxView;
-import org.kie.workbench.common.stunner.core.client.components.toolbox.actions.CreateConnectorAction;
-import org.kie.workbench.common.stunner.core.client.components.toolbox.actions.CreateNodeAction;
+import org.kie.workbench.common.stunner.core.client.components.toolbox.actions.CreateConnectorToolboxAction;
+import org.kie.workbench.common.stunner.core.client.components.toolbox.actions.CreateNodeToolboxAction;
+import org.kie.workbench.common.stunner.core.client.components.toolbox.actions.ToolboxDomainLookups;
 import org.kie.workbench.common.stunner.core.definition.adapter.AdapterManager;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapter;
-import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
+import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionId;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
-import org.kie.workbench.common.stunner.core.lookup.util.CommonLookups;
-import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.core.lookup.domain.CommonDomainLookups;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.Mockito;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.any;
-import static org.mockito.Mockito.anyInt;
-import static org.mockito.Mockito.anyString;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class DMNFlowActionsToolboxFactoryTest {
 
     private static final String DS_ID = "defSetId1";
@@ -63,9 +61,6 @@ public class DMNFlowActionsToolboxFactoryTest {
     private static final String NODE_ID = "nodeDefId1";
     private static final String E_UUID = "e1";
 
-    @Mock
-    private DefinitionUtils definitionUtils;
-
     @Mock
     private DefinitionManager definitionManager;
 
@@ -76,16 +71,22 @@ public class DMNFlowActionsToolboxFactoryTest {
     private DefinitionAdapter definitionAdapter;
 
     @Mock
-    private CommonLookups commonLookups;
+    private ToolboxDomainLookups toolboxLookups;
 
     @Mock
-    private CreateConnectorAction createConnectorAction;
+    private CommonDomainLookups domainLookups;
 
     @Mock
-    private CreateNodeAction createNodeAction;
+    private CreateConnectorToolboxAction createConnectorActionInstance;
+    private ManagedInstanceStub<CreateConnectorToolboxAction> createConnectorAction;
 
     @Mock
-    private ActionsToolboxView view;
+    private CreateNodeToolboxAction createNodeActionInstance;
+    private ManagedInstanceStub<CreateNodeToolboxAction> createNodeAction;
+
+    @Mock
+    private ActionsToolboxView viewInstance;
+    private ManagedInstanceStub<ActionsToolboxView> view;
 
     @Mock
     private AbstractCanvasHandler canvasHandler;
@@ -110,38 +111,32 @@ public class DMNFlowActionsToolboxFactoryTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
-        when(definitionUtils.getDefinitionManager()).thenReturn(definitionManager);
         when(definitionManager.adapters()).thenReturn(adapters);
         when(adapters.forDefinition()).thenReturn(definitionAdapter);
-        when(definitionAdapter.getId(eq(allowedNodeDefinition))).thenReturn(NODE_ID);
-        when(createConnectorAction.setEdgeId(anyString())).thenReturn(createConnectorAction);
-        when(createNodeAction.setEdgeId(anyString())).thenReturn(createNodeAction);
-        when(createNodeAction.setNodeId(anyString())).thenReturn(createNodeAction);
+        when(definitionAdapter.getId(eq(allowedNodeDefinition))).thenReturn(DefinitionId.build(NODE_ID));
+        createConnectorAction = new ManagedInstanceStub<>(createConnectorActionInstance);
+        when(createConnectorActionInstance.setEdgeId(Mockito.<String>any())).thenReturn(createConnectorActionInstance);
+        createNodeAction = new ManagedInstanceStub<>(createNodeActionInstance);
+        when(createNodeActionInstance.setEdgeId(Mockito.<String>any())).thenReturn(createNodeActionInstance);
+        when(createNodeActionInstance.setNodeId(Mockito.<String>any())).thenReturn(createNodeActionInstance);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(diagram.getGraph()).thenReturn(graph);
         when(diagram.getMetadata()).thenReturn(metadata);
         when(metadata.getDefinitionSetId()).thenReturn(DS_ID);
         when(element.getUUID()).thenReturn(E_UUID);
         when(element.asNode()).thenReturn(element);
-        when(commonLookups.getAllowedConnectors(eq(DS_ID),
-                                                eq(element),
-                                                anyInt(),
-                                                anyInt()))
+        when(toolboxLookups.get(Mockito.<String>any())).thenReturn(domainLookups);
+        when(domainLookups.lookupTargetConnectors(eq(element)))
                 .thenReturn(Collections.singleton(EDGE_ID));
-        when(definitionUtils.getDefaultConnectorId(eq(DS_ID)))
-                .thenReturn(EDGE_ID);
-        when(commonLookups.getAllowedTargetDefinitions(eq(DS_ID),
-                                                       eq(graph),
-                                                       eq(element),
-                                                       eq(EDGE_ID),
-                                                       anyInt(),
-                                                       anyInt()))
-                .thenReturn(Collections.singleton(allowedNodeDefinition));
-        this.tested = new DMNFlowActionsToolboxFactory(definitionUtils,
-                                                       commonLookups,
-                                                       () -> createConnectorAction,
-                                                       () -> createNodeAction,
-                                                       () -> view);
+        when(domainLookups.lookupTargetNodes(eq(graph),
+                                             eq(element),
+                                             eq(EDGE_ID)))
+                .thenReturn(Collections.singleton(NODE_ID));
+        view = new ManagedInstanceStub<>(viewInstance);
+        this.tested = new DMNFlowActionsToolboxFactory(toolboxLookups,
+                                                       createConnectorAction,
+                                                       createNodeAction,
+                                                       view);
     }
 
     @Test
@@ -158,21 +153,17 @@ public class DMNFlowActionsToolboxFactoryTest {
         assertEquals(2,
                      actionsToolbox.size());
         final Iterator actionIt = actionsToolbox.iterator();
-        assertEquals(createConnectorAction,
+        assertEquals(createConnectorActionInstance,
                      actionIt.next());
-        assertEquals(createNodeAction,
+        assertEquals(createNodeActionInstance,
                      actionIt.next());
-        verify(createConnectorAction,
+        verify(createConnectorActionInstance,
                times(1)).setEdgeId(eq(EDGE_ID));
-        verify(createNodeAction,
+        verify(createNodeActionInstance,
                times(1)).setEdgeId(eq(EDGE_ID));
-        verify(createNodeAction,
+        verify(createNodeActionInstance,
                times(1)).setNodeId(eq(NODE_ID));
-        verify(view,
+        verify(viewInstance,
                times(1)).init(eq(actionsToolbox));
-        verify(view,
-               times(2)).addButton(any(Glyph.class),
-                                   anyString(),
-                                   any(Consumer.class));
     }
 }
