@@ -21,15 +21,14 @@ import java.util.Collections;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Context;
-import org.kie.workbench.common.dmn.api.definition.v1_1.ContextEntry;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Context;
+import org.kie.workbench.common.dmn.api.definition.model.ContextEntry;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionEditorColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.NameColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
@@ -39,10 +38,11 @@ import org.kie.workbench.common.stunner.core.graph.command.GraphCommandResultBui
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 
 import static org.junit.Assert.assertEquals;
@@ -51,7 +51,7 @@ import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class MoveRowsCommandTest {
 
     protected static final String II1 = "ii1";
@@ -110,8 +110,8 @@ public class MoveRowsCommandTest {
                 setName(new Name(variable));
             }});
             setExpression(new LiteralExpression() {{
-                setText(makeLiteralExpression(variable,
-                                              context.getContextEntry().size()));
+                getText().setValue(makeLiteralExpression(variable,
+                                                         context.getContextEntry().size()));
             }});
         }});
     }
@@ -126,7 +126,7 @@ public class MoveRowsCommandTest {
     }
 
     protected void addUiModelRow(final int rowIndex) {
-        final DMNGridRow uiRow = new DMNGridRow();
+        final GridRow uiRow = new BaseGridRow();
         uiModel.appendRow(uiRow);
         uiModel.setCellValue(rowIndex, 0, new BaseGridCellValue<>(rowIndex + 1));
         uiModel.setCellValue(rowIndex, 1, new BaseGridCellValue<>("name" + rowIndex));
@@ -252,7 +252,7 @@ public class MoveRowsCommandTest {
             assertEquals(rowValueBases[iiRowIndexIterator],
                          context.getContextEntry().get(iiRowIndex).getVariable().getName().getValue());
             assertEquals(makeLiteralExpression(rowValueBases[iiRowIndexIterator], iiRowIndexIterator),
-                         ((LiteralExpression) context.getContextEntry().get(iiRowIndex).getExpression()).getText());
+                         ((LiteralExpression) context.getContextEntry().get(iiRowIndex).getExpression()).getText().getValue());
             iiRowIndexIterator++;
         }
     }
