@@ -21,10 +21,11 @@ import java.util.Optional;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
-import org.kie.workbench.common.dmn.api.definition.v1_1.List;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Relation;
+import org.kie.workbench.common.dmn.api.definition.HasExpression;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
+import org.kie.workbench.common.dmn.api.definition.model.List;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Relation;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.DecisionTableUIModelMapperHelper;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.relation.RelationColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.relation.RelationDefaultValueUtilities;
@@ -39,7 +40,7 @@ import org.kie.workbench.common.stunner.core.graph.command.GraphCommandResultBui
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
@@ -48,13 +49,14 @@ import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberCol
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
+import static org.kie.workbench.common.dmn.client.widgets.grid.model.BaseHasDynamicHeightCell.DEFAULT_HEIGHT;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class AddRelationColumnCommandTest {
 
     @Mock
@@ -99,7 +101,8 @@ public class AddRelationColumnCommandTest {
         this.uiModel.appendColumn(uiRowNumberColumn);
         this.uiModelMapper = new RelationUIModelMapper(() -> uiModel,
                                                        () -> Optional.of(relation),
-                                                       listSelector);
+                                                       listSelector,
+                                                       DEFAULT_HEIGHT);
 
         makeCommand(1);
 
@@ -145,12 +148,12 @@ public class AddRelationColumnCommandTest {
                      relation.getRow().size());
         assertEquals(1,
                      relation.getRow().get(0).getExpression().size());
-        assertTrue(relation.getRow().get(0).getExpression().get(0) instanceof LiteralExpression);
+        assertTrue(relation.getRow().get(0).getExpression().get(0).getExpression() instanceof LiteralExpression);
 
         assertEquals(relation,
                      informationItem.getParent());
         assertEquals(relation.getRow().get(0),
-                     relation.getRow().get(0).getExpression().get(0).getParent());
+                     relation.getRow().get(0).getExpression().get(0).getExpression().getParent());
     }
 
     @Test
@@ -162,7 +165,7 @@ public class AddRelationColumnCommandTest {
         relation.getRow().add(row);
 
         final LiteralExpression existingLiteralExpression = new LiteralExpression();
-        row.getExpression().add(0, existingLiteralExpression);
+        row.getExpression().add(0, HasExpression.wrap(row, existingLiteralExpression));
 
         final Command<GraphCommandExecutionContext, RuleViolation> c = command.newGraphCommand(handler);
 
@@ -180,14 +183,14 @@ public class AddRelationColumnCommandTest {
                      relation.getRow().size());
         assertEquals(2,
                      relation.getRow().get(0).getExpression().size());
-        assertTrue(relation.getRow().get(0).getExpression().get(0) instanceof LiteralExpression);
+        assertTrue(relation.getRow().get(0).getExpression().get(0).getExpression() instanceof LiteralExpression);
         assertEquals(existingLiteralExpression,
-                     relation.getRow().get(0).getExpression().get(1));
+                     relation.getRow().get(0).getExpression().get(1).getExpression());
 
         assertEquals(relation,
                      informationItem.getParent());
         assertEquals(relation.getRow().get(0),
-                     relation.getRow().get(0).getExpression().get(0).getParent());
+                     relation.getRow().get(0).getExpression().get(0).getExpression().getParent());
     }
 
     @Test
@@ -205,8 +208,8 @@ public class AddRelationColumnCommandTest {
 
         final LiteralExpression existingLiteralExpressionFirst = new LiteralExpression();
         final LiteralExpression existingLiteralExpressionLast = new LiteralExpression();
-        row.getExpression().add(existingLiteralExpressionFirst);
-        row.getExpression().add(existingLiteralExpressionLast);
+        row.getExpression().add(HasExpression.wrap(row, existingLiteralExpressionFirst));
+        row.getExpression().add(HasExpression.wrap(row, existingLiteralExpressionLast));
 
         final Command<GraphCommandExecutionContext, RuleViolation> c = command.newGraphCommand(handler);
 
@@ -227,15 +230,15 @@ public class AddRelationColumnCommandTest {
         assertEquals(3,
                      relation.getRow().get(0).getExpression().size());
         assertEquals(existingLiteralExpressionFirst,
-                     relation.getRow().get(0).getExpression().get(0));
-        assertTrue(relation.getRow().get(0).getExpression().get(1) instanceof LiteralExpression);
+                     relation.getRow().get(0).getExpression().get(0).getExpression());
+        assertTrue(relation.getRow().get(0).getExpression().get(1).getExpression() instanceof LiteralExpression);
         assertEquals(existingLiteralExpressionLast,
-                     relation.getRow().get(0).getExpression().get(2));
+                     relation.getRow().get(0).getExpression().get(2).getExpression());
 
         assertEquals(relation,
                      informationItem.getParent());
         assertEquals(relation.getRow().get(0),
-                     relation.getRow().get(0).getExpression().get(1).getParent());
+                     relation.getRow().get(0).getExpression().get(1).getExpression().getParent());
     }
 
     @Test
