@@ -21,7 +21,7 @@ import java.util.Optional;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import elemental2.dom.CSSStyleDeclaration;
-import elemental2.dom.ClientRect;
+import elemental2.dom.DOMRect;
 import elemental2.dom.DOMTokenList;
 import elemental2.dom.Element;
 import elemental2.dom.Event;
@@ -49,10 +49,9 @@ import static org.kie.workbench.common.dmn.client.editors.types.listview.dragand
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.DRAGGING;
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.GRIP;
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.HOVER;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyInt;
-import static org.mockito.Matchers.anyListOf;
-import static org.mockito.Matchers.anyString;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.anyListOf;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -218,7 +217,7 @@ public class DNDListComponentViewTest {
 
         verify(element0).setAttribute(DATA_X_POSITION, 0);
         verify(element2).setAttribute(DATA_X_POSITION, 1);
-        verify(element1, never()).setAttribute(anyString(), anyString());
+        verify(element1, never()).setAttribute(Mockito.<String>any(), Mockito.<String>any());
     }
 
     @Test
@@ -256,7 +255,7 @@ public class DNDListComponentViewTest {
 
         verify(element0, never()).setAttribute(DATA_X_POSITION, 0);
         verify(element2).setAttribute(DATA_X_POSITION, 1);
-        verify(element1, never()).setAttribute(anyString(), anyString());
+        verify(element1, never()).setAttribute(Mockito.<String>any(), Mockito.<String>any());
     }
 
     @Test
@@ -292,7 +291,7 @@ public class DNDListComponentViewTest {
 
         view.consolidateHierarchicalLevel(true);
 
-        verify(element, never()).setAttribute(anyString(), anyString());
+        verify(element, never()).setAttribute(Mockito.<String>any(), Mockito.<String>any());
     }
 
     @Test
@@ -698,6 +697,7 @@ public class DNDListComponentViewTest {
 
         verify(view).clearHover();
         verify(hoverElement.classList, never()).add(HOVER);
+        verify(presenter, never()).highlightLevel(hoverElement);
     }
 
     @Test
@@ -715,6 +715,7 @@ public class DNDListComponentViewTest {
 
         verify(view).clearHover();
         verify(hoverElement.classList).add(HOVER);
+        verify(presenter).highlightLevel(hoverElement);
     }
 
     @Test
@@ -907,15 +908,15 @@ public class DNDListComponentViewTest {
 
         final MouseEvent event = mock(MouseEvent.class);
         final HTMLElement draggingElement = mock(HTMLElement.class);
-        final ClientRect clientRect = mock(ClientRect.class);
+        final DOMRect rect = mock(DOMRect.class);
 
         event.x = 100;
-        clientRect.left = 25;
+        rect.left = 25;
         draggingElement.style = mock(CSSStyleDeclaration.class);
         dragArea.offsetWidth = 300;
 
         when(presenter.getIndentationSize()).thenReturn(50);
-        when(dragArea.getBoundingClientRect()).thenReturn(clientRect);
+        when(dragArea.getBoundingClientRect()).thenReturn(rect);
         doReturn(draggingElement).when(view).getDragging();
 
         view.updateDraggingElementX(event);
@@ -928,15 +929,15 @@ public class DNDListComponentViewTest {
 
         final MouseEvent event = mock(MouseEvent.class);
         final HTMLElement draggingElement = mock(HTMLElement.class);
-        final ClientRect clientRect = mock(ClientRect.class);
+        final DOMRect rect = mock(DOMRect.class);
 
         event.x = 1000;
-        clientRect.left = 25;
+        rect.left = 25;
         draggingElement.style = mock(CSSStyleDeclaration.class);
         dragArea.offsetWidth = 300;
 
         when(presenter.getIndentationSize()).thenReturn(50);
-        when(dragArea.getBoundingClientRect()).thenReturn(clientRect);
+        when(dragArea.getBoundingClientRect()).thenReturn(rect);
         doReturn(draggingElement).when(view).getDragging();
 
         view.updateDraggingElementX(event);
@@ -949,15 +950,15 @@ public class DNDListComponentViewTest {
 
         final MouseEvent event = mock(MouseEvent.class);
         final HTMLElement draggingElement = mock(HTMLElement.class);
-        final ClientRect clientRect = mock(ClientRect.class);
+        final DOMRect rect = mock(DOMRect.class);
 
         event.x = -1000;
-        clientRect.left = 25;
+        rect.left = 25;
         draggingElement.style = mock(CSSStyleDeclaration.class);
         dragArea.offsetWidth = 300;
 
         when(presenter.getIndentationSize()).thenReturn(50);
-        when(dragArea.getBoundingClientRect()).thenReturn(clientRect);
+        when(dragArea.getBoundingClientRect()).thenReturn(rect);
         doReturn(draggingElement).when(view).getDragging();
 
         view.updateDraggingElementX(event);
@@ -970,15 +971,15 @@ public class DNDListComponentViewTest {
 
         final MouseEvent event = mock(MouseEvent.class);
         final HTMLElement draggingElement = mock(HTMLElement.class);
-        final ClientRect clientRect = mock(ClientRect.class);
+        final DOMRect rect = mock(DOMRect.class);
 
         event.y = 100;
-        clientRect.top = 25;
+        rect.top = 25;
         draggingElement.style = mock(CSSStyleDeclaration.class);
         dragArea.offsetHeight = 300;
 
         when(presenter.getItemHeight()).thenReturn(50);
-        when(dragArea.getBoundingClientRect()).thenReturn(clientRect);
+        when(dragArea.getBoundingClientRect()).thenReturn(rect);
         doReturn(draggingElement).when(view).getDragging();
 
         final int actualYPosition = view.getNewDraggingYPosition(event);
@@ -992,15 +993,15 @@ public class DNDListComponentViewTest {
 
         final MouseEvent event = mock(MouseEvent.class);
         final HTMLElement draggingElement = mock(HTMLElement.class);
-        final ClientRect clientRect = mock(ClientRect.class);
+        final DOMRect rect = mock(DOMRect.class);
 
         event.y = 1000;
-        clientRect.top = 25;
+        rect.top = 25;
         draggingElement.style = mock(CSSStyleDeclaration.class);
         dragArea.offsetHeight = 300;
 
         when(presenter.getItemHeight()).thenReturn(50);
-        when(dragArea.getBoundingClientRect()).thenReturn(clientRect);
+        when(dragArea.getBoundingClientRect()).thenReturn(rect);
         doReturn(draggingElement).when(view).getDragging();
 
         final int actualYPosition = view.getNewDraggingYPosition(event);
