@@ -15,28 +15,30 @@
  */
 package org.kie.workbench.common.dmn.client.shape.view.handlers;
 
+import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.DMNViewDefinition;
+import org.kie.workbench.common.dmn.api.property.dimensions.GeneralRectangleDimensionsSet;
 import org.kie.workbench.common.dmn.api.property.dimensions.Height;
 import org.kie.workbench.common.dmn.api.property.dimensions.RectangleDimensionsSet;
 import org.kie.workbench.common.dmn.api.property.dimensions.Width;
+import org.kie.workbench.common.dmn.api.property.font.FontSet;
 import org.kie.workbench.common.dmn.client.shape.def.DMNSVGShapeDefImpl;
+import org.kie.workbench.common.stunner.core.client.shape.TextWrapperStrategy;
+import org.kie.workbench.common.stunner.core.client.shape.view.handler.FontHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.handler.SizeHandler;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundImpl;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.svg.client.shape.view.SVGShapeView;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.verify;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(GwtMockitoTestRunner.class)
 public class DMNViewHandlersTest {
 
     @Mock
@@ -48,11 +50,10 @@ public class DMNViewHandlersTest {
     @Mock
     private SVGShapeView shape;
 
-    private Bounds bounds = new BoundsImpl(new BoundImpl(0.0, 0.0),
-                                           new BoundImpl(100.0, 100.0));
+    private Bounds bounds = Bounds.create(0.0, 0.0, 100.0, 100.0);
 
-    private RectangleDimensionsSet dimensions = new RectangleDimensionsSet(new Width(50.0),
-                                                                           new Height(50.0));
+    private RectangleDimensionsSet dimensions = new GeneralRectangleDimensionsSet(new Width(50.0),
+                                                                                  new Height(50.0));
 
     @Before
     public void setup() {
@@ -60,6 +61,8 @@ public class DMNViewHandlersTest {
         doReturn(bounds).when(view).getBounds();
 
         doReturn(dimensions).when(definition).getDimensionsSet();
+
+        doReturn(new FontSet()).when(definition).getFontSet();
     }
 
     @Test
@@ -68,9 +71,19 @@ public class DMNViewHandlersTest {
         handler.handle(view,
                        shape);
 
-        verify(shape).setMinWidth(eq(Width.MIN));
-        verify(shape).setMaxWidth(eq(Width.MAX));
-        verify(shape).setMinHeight(eq(Height.MIN));
-        verify(shape).setMaxHeight(eq(Height.MAX));
+        verify(shape).setMinWidth(eq(dimensions.getMinimumWidth()));
+        verify(shape).setMaxWidth(eq(dimensions.getMaximumWidth()));
+        verify(shape).setMinHeight(eq(dimensions.getMinimumHeight()));
+        verify(shape).setMaxHeight(eq(dimensions.getMaximumHeight()));
+    }
+
+    @Test
+    public void testNewFontHandler() {
+
+        final FontHandler<DMNViewDefinition, SVGShapeView> handler = new DMNSVGShapeDefImpl().newFontHandler();
+        handler.handle(definition,
+                       shape);
+
+        verify(shape).setTextWrapper(TextWrapperStrategy.TRUNCATE);
     }
 }
