@@ -17,6 +17,7 @@
 package org.kie.workbench.common.screens.datamodeller.client;
 
 import java.util.List;
+import java.util.function.Consumer;
 
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
@@ -24,6 +25,8 @@ import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
 import com.google.gwt.user.client.ui.IsWidget;
+import elemental2.promise.Promise;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.validation.model.ValidationMessage;
 import org.guvnor.messageconsole.events.PublishBaseEvent;
 import org.guvnor.messageconsole.events.PublishBatchMessagesEvent;
@@ -78,7 +81,6 @@ import org.uberfire.client.annotations.WorkbenchPartTitleDecoration;
 import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.client.mvp.LockRequiredEvent;
 import org.uberfire.client.views.pfly.multipage.PageImpl;
-import org.uberfire.client.workbench.events.PlaceHiddenEvent;
 import org.uberfire.ext.editor.commons.client.file.CommandWithFileNameAndCommitMessage;
 import org.uberfire.ext.editor.commons.client.file.FileNameAndCommitMessage;
 import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
@@ -98,113 +100,66 @@ import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.Menus;
 
 @Dependent
-@WorkbenchEditor(identifier = "DataModelerEditor",
+@WorkbenchEditor(identifier = DataModelerScreenPresenter.EDITOR_ID,
         supportedTypes = {JavaResourceType.class},
         priority = Integer.MAX_VALUE)
 public class DataModelerScreenPresenter
         extends KieEditor<String> {
 
-    public interface DataModelerScreenView
-            extends
-            KieEditorView {
-
-        void setContext(DataModelerContext context);
-
-        void refreshTypeLists(boolean keepCurrentSelection);
-
-        void showYesNoCancelPopup(String title,
-                                  String message,
-                                  Command yesCommand,
-                                  String yesButtonText,
-                                  ButtonType yesButtonType,
-                                  Command noCommand,
-                                  String noButtonText,
-                                  ButtonType noButtonType);
-
-        void showYesNoCancelPopup(String title,
-                                  String message,
-                                  Command yesCommand,
-                                  Command noCommand);
-
-        void showParseErrorsDialog(String title,
-                                   String message,
-                                   Command onCloseCommand);
-
-        void setDomainContainerTitle(String title,
-                                     String tooltip);
-
-        void redraw();
-    }
-
-    protected DataModelerScreenView view;
-
-    @Inject
-    protected EditJavaSourceWidget javaSourceEditor;
-
-    @Inject
-    protected Event<DataModelerEvent> dataModelerEvent;
-
-    @Inject
-    protected Event<UnpublishMessagesEvent> unpublishMessagesEvent;
-
-    @Inject
-    protected Event<PublishBatchMessagesEvent> publishBatchMessagesEvent;
-
-    @Inject
-    protected Event<LockRequiredEvent> lockRequired;
-
-    @Inject
-    protected Event<DataModelerWorkbenchFocusEvent> dataModelerFocusEvent;
-
-    @Inject
-    protected Caller<DataModelerService> modelerService;
-
-    @Inject
-    protected ValidationPopup validationPopup;
-
-    @Inject
-    protected ValidatorService validatorService;
-
-    @Inject
-    protected Caller<ValidationService> validationService;
-
-    @Inject
-    protected JavaAssetUpdateValidator javaAssetUpdateValidator;
-
-    @Inject
-    protected JavaResourceType resourceType;
-
-    @Inject
-    protected DataModelerWorkbenchContext dataModelerWBContext;
-
-    @Inject
-    protected AuthorizationManager authorizationManager;
-
-    @Inject
-    protected ShowAssetUsagesDisplayer showAssetUsagesDisplayer;
-
-    protected DataModelerContext context;
-
-    protected boolean uiStarted = false;
-
-    protected boolean loading = false;
-
-    private boolean loadTypesInfo = false;
-
-    private SessionInfo sessionInfo;
-
-    private String currentMessageType;
-
-    private Integer originalSourceHash = null;
-
-    private boolean sourceEditionEnabled = false;
+    public static final String EDITOR_ID = "DataModelerEditor";
 
     private static final int EDITABLE_SOURCE_TAB = 2;
-
     private static int editorIds = 0;
-
+    protected DataModelerScreenView view;
+    @Inject
+    protected EditJavaSourceWidget javaSourceEditor;
+    @Inject
+    protected Event<DataModelerEvent> dataModelerEvent;
+    @Inject
+    protected Event<UnpublishMessagesEvent> unpublishMessagesEvent;
+    @Inject
+    protected Event<PublishBatchMessagesEvent> publishBatchMessagesEvent;
+    @Inject
+    protected Event<LockRequiredEvent> lockRequired;
+    @Inject
+    protected Event<DataModelerWorkbenchFocusEvent> dataModelerFocusEvent;
+    @Inject
+    protected Caller<DataModelerService> modelerService;
+    @Inject
+    protected ValidationPopup validationPopup;
+    @Inject
+    protected ValidatorService validatorService;
+    @Inject
+    protected Caller<ValidationService> validationService;
+    @Inject
+    protected JavaAssetUpdateValidator javaAssetUpdateValidator;
+    @Inject
+    protected JavaResourceType resourceType;
+    @Inject
+    protected DataModelerWorkbenchContext dataModelerWBContext;
+    @Inject
+    protected AuthorizationManager authorizationManager;
+    @Inject
+    protected ShowAssetUsagesDisplayer showAssetUsagesDisplayer;
+    protected DataModelerContext context;
+    protected boolean uiStarted = false;
+    protected boolean loading = false;
+    private boolean loadTypesInfo = false;
+    private SessionInfo sessionInfo;
+    private String currentMessageType;
+    private Integer originalSourceHash = null;
+    private boolean sourceEditionEnabled = false;
     private String editorId;
 
+    @Inject
+    public DataModelerScreenPresenter(DataModelerScreenView baseView,
+                                      SessionInfo sessionInfo) {
+        super(baseView);
+        view = baseView;
+        this.sessionInfo = sessionInfo;
+        editorId = sessionInfo.getId() + "-" + editorIds++;
+    }
+
     @WorkbenchPartTitle
     public String getTitleText() {
         return super.getTitleText();
@@ -221,17 +176,8 @@ public class DataModelerScreenPresenter
     }
 
     @WorkbenchMenu
-    public Menus getMenus() {
-        return menus;
-    }
-
-    @Inject
-    public DataModelerScreenPresenter(DataModelerScreenView baseView,
-                                      SessionInfo sessionInfo) {
-        super(baseView);
-        view = baseView;
-        this.sessionInfo = sessionInfo;
-        editorId = sessionInfo.getId() + "-" + editorIds++;
+    public void getMenus(final Consumer<Menus> menusConsumer) {
+        super.getMenus(menusConsumer);
     }
 
     @OnStartup
@@ -261,37 +207,47 @@ public class DataModelerScreenPresenter
 
     @OnFocus
     public void onFocus() {
-        if (!loading && context != null) {
+        if (!loading && context != null && workbenchContext.getActiveModule().isPresent()) {
             view.redraw();
             setActiveContext();
-            showDataModellerDocks();
         }
     }
 
+    @Override
+    public void showDocks() {
+        super.showDocks();
+        showDataModellerDocks();
+    }
+
     private void showDataModellerDocks() {
         dataModelerFocusEvent.fire(new DataModelerWorkbenchFocusEvent());
     }
 
-    private void hideDataModellerDocks(@Observes PlaceHiddenEvent event) {
+    @Override
+    public void hideDocks() {
+        super.hideDocks();
         if (context != null) {
-            if ("DataModelerEditor".equals(event.getPlace().getIdentifier()) &&
-                    place != null && place.equals(event.getPlace())) {
-                dataModelerFocusEvent.fire(new DataModelerWorkbenchFocusEvent().lostFocus());
-            }
+            dataModelerFocusEvent.fire(new DataModelerWorkbenchFocusEvent().lostFocus());
         }
     }
 
+    @Override
+    protected String getEditorIdentifier() {
+        return EDITOR_ID;
+    }
+
     @OnMayClose
     public boolean onMayClose() {
         return !isDirty();
     }
 
     @OnClose
-    public void OnClose() {
+    @Override
+    public void onClose() {
         versionRecordManager.clear();
         cleanSystemMessages(getCurrentMessageType());
         clearContext();
-        super.OnClose();
+        super.onClose();
         dataModelerWBContext.clearContext();
     }
 
@@ -568,60 +524,45 @@ public class DataModelerScreenPresenter
         }
     }
 
+    private Command getSaveFileCommand(JavaTypeInfo newTypeInfo) {
+        return () -> {
+            ObservablePath latestPath = versionRecordManager.getPathToLatest();
+            ParameterizedCommand<String> command = getSaveCommand(newTypeInfo, latestPath);
+
+            if (saveWithComments) {
+                savePopUpPresenter.show(latestPath, command);
+
+            } else {
+               command.execute("");
+            }
+        };
+    }
+
     private void saveFile(final JavaTypeInfo newTypeInfo) {
 
         String currentFileName = DataModelerUtils.extractSimpleFileName(versionRecordManager.getPathToLatest());
 
         if (hasPackageNameChanged(newTypeInfo)) {
-
             view.showYesNoCancelPopup(CommonConstants.INSTANCE.Information(),
                                       Constants.INSTANCE.modelEditor_confirm_file_package_refactoring(newTypeInfo.getPackageName()),
-                                      new Command() {
-                                          @Override
-                                          public void execute() {
-                                              savePopUpPresenter.show(versionRecordManager.getPathToLatest(),
-                                                                      getSaveCommand(newTypeInfo,
-                                                                                     versionRecordManager.getPathToLatest()));
-                                          }
-                                      },
+                                      getSaveFileCommand(newTypeInfo),
                                       Constants.INSTANCE.modelEditor_action_yes_refactor_directory(),
                                       ButtonType.PRIMARY,
-                                      new Command() {
-                                          @Override
-                                          public void execute() {
-                                              savePopUpPresenter.show(versionRecordManager.getPathToLatest(),
-                                                                      getSaveCommand(versionRecordManager.getPathToLatest()));
-                                          }
-                                      },
+                                      getSaveFileCommand(null),
                                       Constants.INSTANCE.modelEditor_action_no_dont_refactor_directory(),
                                       ButtonType.DANGER);
-        } else if (hasFileNameChanged(newTypeInfo,
-                                      currentFileName)) {
 
+        } else if (hasFileNameChanged(newTypeInfo, currentFileName)) {
             view.showYesNoCancelPopup(CommonConstants.INSTANCE.Information(),
                                       Constants.INSTANCE.modelEditor_confirm_file_name_refactoring(newTypeInfo.getName()),
-                                      new Command() {
-                                          @Override
-                                          public void execute() {
-                                              savePopUpPresenter.show(versionRecordManager.getPathToLatest(),
-                                                                      getSaveCommand(newTypeInfo,
-                                                                                     versionRecordManager.getPathToLatest()));
-                                          }
-                                      },
+                                      getSaveFileCommand(newTypeInfo),
                                       Constants.INSTANCE.modelEditor_action_yes_refactor_file_name(),
                                       ButtonType.PRIMARY,
-                                      new Command() {
-                                          @Override
-                                          public void execute() {
-                                              savePopUpPresenter.show(versionRecordManager.getPathToLatest(),
-                                                                      getSaveCommand(versionRecordManager.getPathToLatest()));
-                                          }
-                                      },
+                                      getSaveFileCommand(null),
                                       Constants.INSTANCE.modelEditor_action_no_dont_refactor_file_name(),
                                       ButtonType.DANGER);
         } else {
-            savePopUpPresenter.show(versionRecordManager.getPathToLatest(),
-                                    getSaveCommand(versionRecordManager.getPathToLatest()));
+            getSaveFileCommand(null).execute();
         }
     }
 
@@ -647,23 +588,16 @@ public class DataModelerScreenPresenter
 
                 final DataObject[] modifiedDataObject = new DataObject[1];
                 if (isDirty()) {
-                    if (context.isEditorChanged()) {
-
-                        //at save time the source has always priority over the model.
-                        //If the source was properly parsed and the editor has changes, we need to send the DataObject
-                        //to the server in order to let the source to be updated prior to save.
-                        modifiedDataObject[0] = context.getDataObject();
-                    } else {
-                        //if the source has changes, no update form the UI to the source will be performed.
-                        //instead the parsed DataObject must be returned from the server.
-                        modifiedDataObject[0] = null;
-                    }
+                    /* when DataObject editor or source is changed we
+                     * need to send the DataObject to the server  in order
+                     *  to let the source to be updated prior to save.
+                     */
+                    modifiedDataObject[0] = context.getDataObject();
                 }
                 view.showSaving();
 
                 if (newTypeInfo != null) {
-                    modelerService.call(getSaveSuccessCallback(newTypeInfo,
-                                                               path),
+                    modelerService.call(getSaveSuccessCallback(path),
                                         new DataModelerErrorCallback(Constants.INSTANCE.modelEditor_saving_error())).saveSource(
                             getSource(),
                             path,
@@ -673,8 +607,7 @@ public class DataModelerScreenPresenter
                             newTypeInfo.getPackageName(),
                             newTypeInfo.getName());
                 } else {
-                    modelerService.call(getSaveSuccessCallback(newTypeInfo,
-                                                               path),
+                    modelerService.call(getSaveSuccessCallback(path),
                                         new DataModelerErrorCallback(Constants.INSTANCE.modelEditor_saving_error())).saveSource(
                             getSource(),
                             path,
@@ -686,8 +619,7 @@ public class DataModelerScreenPresenter
         };
     }
 
-    private RemoteCallback<GenerationResult> getSaveSuccessCallback(final JavaTypeInfo newTypeInfo,
-                                                                    final Path currentPath) {
+    private RemoteCallback<GenerationResult> getSaveSuccessCallback(final Path currentPath) {
         return new RemoteCallback<GenerationResult>() {
 
             @Override
@@ -695,8 +627,6 @@ public class DataModelerScreenPresenter
 
                 view.hideBusyIndicator();
 
-                if (newTypeInfo == null) {
-
                     Boolean oldDirtyStatus = isDirty();
 
                     if (result.hasErrors()) {
@@ -737,14 +667,6 @@ public class DataModelerScreenPresenter
                                                              null));
 
                     versionRecordManager.reloadVersions(currentPath);
-                } else {
-                    notification.fire(new NotificationEvent(
-                            org.uberfire.ext.editor.commons.client.resources.i18n.CommonConstants.INSTANCE.ItemRenamedSuccessfully(),
-                            NotificationEvent.NotificationType.SUCCESS));
-                    //If the file was renamed as part of the file saving, don't do anything.
-                    //A rename event will arrive, the same as for the "Rename" case.
-                    //and the file will be automatically reloaded.
-                }
             }
         };
     }
@@ -762,42 +684,46 @@ public class DataModelerScreenPresenter
 
             @Override
             public void callback(EditorModelContent content) {
+                isReadOnly().then(isReadOnly -> {
+                    //Path is set to null when the Editor is closed (which can happen before async calls complete).
+                    if (versionRecordManager.getCurrentPath() == null) {
+                        return promises.resolve();
+                    }
 
-                //Path is set to null when the Editor is closed (which can happen before async calls complete).
-                if (versionRecordManager.getCurrentPath() == null) {
-                    return;
-                }
+                    uiStarted = false;
+                    resetEditorPages(content.getOverview());
+                    addSourceEditorPage();
+                    uiStarted = true;
 
-                uiStarted = false;
-                resetEditorPages(content.getOverview());
-                addSourceEditorPage();
-                uiStarted = true;
+                    initContext(content,
+                                isReadOnly);
+                    javaSourceEditor.setReadonly(isReadOnly || !sourceEditionEnabled);
+                    javaSourceEditor.setContent(content.getSource());
 
-                initContext(content);
-                javaSourceEditor.setReadonly(isReadOnly || !sourceEditionEnabled);
-                javaSourceEditor.setContent(content.getSource());
+                    view.hideBusyIndicator();
 
-                view.hideBusyIndicator();
+                    if (content.hasErrors()) {
+                        publishSystemMessages(getCurrentMessageType(),
+                                              true,
+                                              content.getErrors());
+                    }
 
-                if (content.hasErrors()) {
-                    publishSystemMessages(getCurrentMessageType(),
-                                          true,
-                                          content.getErrors());
-                }
+                    if (content.getDataObject() != null) {
+                        selectEditorTab();
+                    } else {
+                        showParseErrorsDialog(Constants.INSTANCE.modelEditor_message_file_parsing_errors(),
+                                              false,
+                                              context.getEditorModelContent().getErrors(),
+                                              getOnLoadParseErrorCommand());
+                    }
 
-                if (content.getDataObject() != null) {
-                    selectEditorTab();
-                } else {
-                    showParseErrorsDialog(Constants.INSTANCE.modelEditor_message_file_parsing_errors(),
-                                          false,
-                                          context.getEditorModelContent().getErrors(),
-                                          getOnLoadParseErrorCommand());
-                }
+                    showDataModellerDocks();
+                    setOriginalHash(context.getDataObject() != null ? context.getDataObject().hashCode() : null);
+                    originalSourceHash = getSource().hashCode();
+                    loading = false;
 
-                showDataModellerDocks();
-                setOriginalHash(context.getDataObject() != null ? context.getDataObject().hashCode() : null);
-                originalSourceHash = getSource().hashCode();
-                loading = false;
+                    return promises.resolve();
+                });
             }
         };
     }
@@ -943,8 +869,8 @@ public class DataModelerScreenPresenter
                                                               sessionInfo.getIdentity());
     }
 
-    private void initContext(EditorModelContent content) {
-
+    private void initContext(final EditorModelContent content,
+                             final boolean isReadOnly) {
         if (loadTypesInfo) {
             dataModelerWBContext.setAnnotationDefinitions(content.getAnnotationDefinitions());
             dataModelerWBContext.setPropertyTypes(content.getPropertyTypes());
@@ -963,7 +889,7 @@ public class DataModelerScreenPresenter
             context.setParseStatus(DataModelerContext.ParseStatus.PARSE_ERRORS);
             context.setEditionMode(DataModelerContext.EditionMode.SOURCE_MODE);
         }
-    }
+   }
 
     @Override
     public void onSourceTabSelected() {
@@ -1191,6 +1117,9 @@ public class DataModelerScreenPresenter
         unpublishMessage.setShowSystemConsole(false);
         unpublishMessage.setMessageType(currentMessageType);
         unpublishMessage.setUserId((sessionInfo != null && sessionInfo.getIdentity() != null) ? sessionInfo.getIdentity().getIdentifier() : null);
+        if (workbenchContext.getActiveModule().isPresent()) {
+            unpublishMessage.setRootPath(workbenchContext.getActiveModule().get().getRootPath().toURI());
+        }
         unpublishMessagesEvent.fire(unpublishMessage);
     }
 
@@ -1214,45 +1143,41 @@ public class DataModelerScreenPresenter
             systemMessage.setColumn(error.getColumn());
             publishMessage.getMessagesToPublish().add(systemMessage);
         }
+        if (workbenchContext.getActiveModule().isPresent()) {
+            publishMessage.setRootPath(workbenchContext.getActiveModule().get().getRootPath().toURI());
+        }
+
         publishBatchMessagesEvent.fire(publishMessage);
     }
 
     @Override
-    protected void makeMenuBar() {
-        if (canUpdateProject()) {
-            fileMenuBuilder
-                    .addSave(versionRecordManager.newSaveMenuItem(new Command() {
-                        @Override
-                        public void execute() {
-                            saveAction();
-                        }
-                    }))
-                    .addCopy(new Command() {
-                        @Override
-                        public void execute() {
-                            onCopy();
-                        }
-                    })
-                    .addRename(new Command() {
-                        @Override
-                        public void execute() {
-                            onSafeRename();
-                        }
-                    })
-                    .addDelete(new Command() {
-                        @Override
-                        public void execute() {
-                            onSafeDelete();
-                        }
-                    });
+    protected Promise<Void> makeMenuBar() {
+        if (!workbenchContext.getActiveWorkspaceProject().isPresent()) {
+            return promises.resolve();
         }
 
-        fileMenuBuilder
-                .addValidate(
-                        getValidateCommand()
-                )
-                .addNewTopLevelMenu(versionRecordManager.buildMenu())
-                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+        final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().get();
+
+        return projectController.canUpdateProject(activeProject).then(canUpdateProject -> {
+            if (canUpdateProject) {
+                final ParameterizedCommand<Boolean> onSave = withComments -> {
+                    saveWithComments = withComments;
+                    saveAction();
+                };
+                fileMenuBuilder.addSave(versionRecordManager.newSaveMenuItem(onSave))
+                               .addCopy(() -> onCopy())
+                               .addRename(() -> onSafeRename())
+                               .addDelete(() -> onSafeDelete());
+            }
+
+            addDownloadMenuItem(fileMenuBuilder);
+
+            fileMenuBuilder.addValidate(getValidateCommand())
+                           .addNewTopLevelMenu(versionRecordManager.buildMenu())
+                           .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+
+            return promises.resolve();
+        });
     }
 
     private void clearContext() {
@@ -1297,4 +1222,49 @@ public class DataModelerScreenPresenter
                                                                  true));
         }
     }
-}
\ No newline at end of file
+
+    private Promise<Boolean> isReadOnly() {
+        if (super.isReadOnly) {
+            return promises.resolve(true);
+        }
+
+        if (workbenchContext.getActiveWorkspaceProject().isPresent()) {
+            final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().get();
+            return projectController.canUpdateProject(activeProject).then(canUpdateProject -> promises.resolve(!canUpdateProject));
+        }
+
+        return promises.resolve(false);
+    }
+
+    public interface DataModelerScreenView
+            extends
+            KieEditorView {
+
+        void setContext(DataModelerContext context);
+
+        void refreshTypeLists(boolean keepCurrentSelection);
+
+        void showYesNoCancelPopup(String title,
+                                  String message,
+                                  Command yesCommand,
+                                  String yesButtonText,
+                                  ButtonType yesButtonType,
+                                  Command noCommand,
+                                  String noButtonText,
+                                  ButtonType noButtonType);
+
+        void showYesNoCancelPopup(String title,
+                                  String message,
+                                  Command yesCommand,
+                                  Command noCommand);
+
+        void showParseErrorsDialog(String title,
+                                   String message,
+                                   Command onCloseCommand);
+
+        void setDomainContainerTitle(String title,
+                                     String tooltip);
+
+        void redraw();
+    }
+}
