@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.screens.library.api.preferences;
 
+import org.guvnor.common.services.project.preferences.GAVPreferences;
 import org.uberfire.preferences.shared.annotations.Property;
 import org.uberfire.preferences.shared.annotations.WorkbenchPreference;
 import org.uberfire.preferences.shared.bean.BasePreference;
@@ -23,24 +24,30 @@ import org.uberfire.preferences.shared.bean.BasePreference;
 @WorkbenchPreference(identifier = "LibraryPreferences",
         bundleKey = "LibraryPreferences.Label")
 public class LibraryPreferences implements BasePreference<LibraryPreferences> {
-
+    
     @Property(bundleKey = "LibraryPreferences.OrganizationalUnitPreferences")
     LibraryOrganizationalUnitPreferences organizationalUnitPreferences;
 
     @Property(bundleKey = "LibraryPreferences.ProjectPreferences")
     LibraryProjectPreferences projectPreferences;
 
+    @Property(bundleKey = "LibraryPreferences.AdvancedGavPreferences", shared = true)
+    GAVPreferences gavPreferences;
+
     @Override
     public LibraryPreferences defaultValue(final LibraryPreferences defaultValue) {
-        defaultValue.organizationalUnitPreferences.name = "myteam";
+        defaultValue.organizationalUnitPreferences.name = "MySpace";
         defaultValue.organizationalUnitPreferences.owner = "admin";
-        defaultValue.organizationalUnitPreferences.groupId = "com.myteam";
+        defaultValue.organizationalUnitPreferences.groupId = "com.myspace";
         defaultValue.organizationalUnitPreferences.aliasInSingular = "";
         defaultValue.organizationalUnitPreferences.aliasInPlural = "";
 
-        defaultValue.projectPreferences.version = "1.0.0";
+        defaultValue.projectPreferences.version = "1.0.0-SNAPSHOT";
         defaultValue.projectPreferences.description = "";
         defaultValue.projectPreferences.branch = "master";
+        //GWT complains in SuperDevMode if the static constants are used; so we have to use a literal
+        defaultValue.projectPreferences.assetsPerPage = System.getProperty("org.kie.library.assets_per_page",
+                                                                           "15");
 
         return defaultValue;
     }
@@ -52,4 +59,12 @@ public class LibraryPreferences implements BasePreference<LibraryPreferences> {
     public LibraryProjectPreferences getProjectPreferences() {
         return projectPreferences;
     }
+
+    public GAVPreferences getGavPreferences() {
+        return gavPreferences;
+    }
+
+    public void setGavPreferences(GAVPreferences gavPreferences) {
+        this.gavPreferences = gavPreferences;
+    }
 }
