@@ -28,7 +28,6 @@ import java.util.Set;
 import java.util.stream.Collectors;
 
 import javax.enterprise.context.ApplicationScoped;
-import javax.enterprise.event.Event;
 import javax.inject.Inject;
 import javax.inject.Named;
 
@@ -52,6 +51,8 @@ import org.guvnor.structure.security.RepositoryAction;
 import org.jboss.errai.bus.server.annotations.Service;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.jboss.errai.security.shared.exception.UnauthorizedException;
+import org.kie.workbench.common.screens.archetype.mgmt.shared.model.Archetype;
+import org.kie.workbench.common.screens.archetype.mgmt.shared.services.ArchetypeService;
 import org.kie.workbench.common.screens.examples.model.ExampleRepository;
 import org.kie.workbench.common.screens.examples.model.ImportProject;
 import org.kie.workbench.common.screens.examples.service.ExamplesService;
@@ -96,6 +97,8 @@ public class LibraryServiceImpl implements LibraryService {
 
     private static final Logger log = LoggerFactory.getLogger(LibraryServiceImpl.class);
 
+    private static final String DEFAULT_PROJECT_NAME = "MyProject";
+
     private RefactoringQueryService refactoringQueryService;
     private OrganizationalUnitService ouService;
     private LibraryPreferences preferences;
@@ -110,6 +113,7 @@ public class LibraryServiceImpl implements LibraryService {
     private IndexStatusOracle indexOracle;
     private SpaceConfigStorageRegistry spaceConfigStorageRegistry;
     private ClusterService clusterService;
+    private ArchetypeService archetypeService;
 
     public LibraryServiceImpl() {
     }
@@ -128,7 +132,8 @@ public class LibraryServiceImpl implements LibraryService {
                               final UserManagerService userManagerService,
                               final IndexStatusOracle indexOracle,
                               final SpaceConfigStorageRegistry spaceConfigStorageRegistry,
-                              final ClusterService clusterService) {
+                              final ClusterService clusterService,
+                              final ArchetypeService archetypeService) {
         this.ouService = ouService;
         this.refactoringQueryService = refactoringQueryService;
         this.preferences = preferences;
@@ -143,6 +148,7 @@ public class LibraryServiceImpl implements LibraryService {
         this.indexOracle = indexOracle;
         this.spaceConfigStorageRegistry = spaceConfigStorageRegistry;
         this.clusterService = clusterService;
+        this.archetypeService = archetypeService;
     }
 
     @Override
@@ -182,6 +188,29 @@ public class LibraryServiceImpl implements LibraryService {
                 || project.getRepository().getContributors().stream().anyMatch(c -> c.getUsername().equals(sessionInfo.getIdentity().getIdentifier()));
     }
 
+    @Override
+    public WorkspaceProject createProject(final OrganizationalUnit organizationalUnit,
+                                          final String remoteRepositoryUrl,
+                                          final String repositoryAlias) {
+        final String projectName = repositoryAlias != null ? repositoryAlias : DEFAULT_PROJECT_NAME;
+
+        final Optional<Archetype> baseArchetype = archetypeService.getBaseKieArchetype();
+
+        final String baseArchetypeAlias = baseArchetype.map(Archetype::getAlias).orElse(null);
+
+        final GAV gav = createGAV(projectName,
+                                  organizationalUnit);
+        final POM pom = createPOM(projectName,
+                                  projectName,
+                                  gav);
+
+        return createProject(organizationalUnit,
+                             pom,
+                             DeploymentMode.VALIDATED,
+                             baseArchetypeAlias,
+                             remoteRepositoryUrl);
+    }
+
     @Override
     public WorkspaceProject createProject(final String projectName,
                                           final OrganizationalUnit selectedOrganizationalUnit,
@@ -203,10 +232,36 @@ public class LibraryServiceImpl implements LibraryService {
     public WorkspaceProject createProject(final OrganizationalUnit activeOrganizationalUnit,
                                           final POM pom,
                                           final DeploymentMode mode) {
+        return createProject(activeOrganizationalUnit,
+                             pom,
+                             mode,
+                             null);
+    }
+
+    @Override
+    public WorkspaceProject createProject(final OrganizationalUnit activeOrganizationalUnit,
+                                          final POM pom,
+                                          final DeploymentMode mode,
+                                          final String templateId) {
+        return createProject(activeOrganizationalUnit,
+                             pom,
+                             mode,
+                             templateId,
+                             null);
+    }
+
+    @Override
+    public WorkspaceProject createProject(final OrganizationalUnit activeOrganizationalUnit,
+                                          final POM pom,
+                                          final DeploymentMode mode,
+                                          final String templateId,
+                                          final String remoteRepositoryUrl) {
         return projectService.newProject(activeOrganizationalUnit,
                                          pom,
                                          mode,
-                                         getRepositoryContributors(activeOrganizationalUnit));
+                                         getRepositoryContributors(activeOrganizationalUnit),
+                                         resolveTemplateRepository(templateId),
+                                         remoteRepositoryUrl);
     }
 
     private List<Contributor> getRepositoryContributors(final OrganizationalUnit organizationalUnit) {
@@ -230,6 +285,14 @@ public class LibraryServiceImpl implements LibraryService {
         return contributors;
     }
 
+    private Repository resolveTemplateRepository(final String templateId) {
+        if (templateId != null) {
+            return archetypeService.getTemplateRepository(templateId);
+        } else {
+            return archetypeService.getBaseKieTemplateRepository().orElse(null);
+        }
+    }
+
     @Override
     public Boolean thereIsAProjectInTheWorkbench() {
         return !projectService.getAllWorkspaceProjects().isEmpty();
