@@ -16,31 +16,44 @@
 package org.kie.workbench.common.screens.library.client.screens.project;
 
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import java.util.Optional;
 
 import javax.enterprise.event.Event;
 
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
+import org.guvnor.common.services.project.client.preferences.SpaceScopedResolutionStrategySupplier;
 import org.guvnor.common.services.project.client.repositories.ConflictingRepositoriesPopup;
 import org.guvnor.common.services.project.events.NewProjectEvent;
 import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.DeploymentMode;
+import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.screens.archetype.mgmt.shared.preferences.ArchetypePreferences;
 import org.kie.workbench.common.screens.library.api.LibraryInfo;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryOrganizationalUnitPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryProjectPreferences;
+import org.kie.workbench.common.screens.library.client.resources.i18n.LibraryConstants;
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
+import org.kie.workbench.common.services.refactoring.model.index.events.IndexingFinishedEvent;
 import org.kie.workbench.common.services.shared.validation.ValidationService;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.Mockito;
+import org.mockito.junit.MockitoJUnitRunner;
+import org.slf4j.Logger;
+import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.views.pfly.widgets.ErrorPopup;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
@@ -51,10 +64,19 @@ import org.uberfire.rpc.SessionInfo;
 import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.jgroups.util.Util.assertEquals;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.doThrow;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 import static org.uberfire.mocks.ParametrizedCommandMock.executeParametrizedCommandWith;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class AddProjectPopUpPresenterTest {
 
     @Mock
@@ -97,15 +119,29 @@ public class AddProjectPopUpPresenterTest {
     @Mock
     private TranslationService translationService;
 
+    @Mock
+    private WorkspaceProjectService projectService;
+    private CallerMock<WorkspaceProjectService> projectServiceCaller;
+
+    @Mock
+    private Logger logger;
+
     private AddProjectPopUpPresenter presenter;
 
     private LibraryInfo libraryInfo;
     private OrganizationalUnit selectedOrganizationalUnit;
 
+    @Mock
+    private ArchetypePreferences archetypePreferences;
+
+    @Mock
+    private SpaceScopedResolutionStrategySupplier spaceScopedResolutionStrategySupplier;
+
     @Before
     public void setup() {
         libraryServiceCaller = new CallerMock<>(libraryService);
         validationServiceCaller = new CallerMock<>(validationService);
+        projectServiceCaller = new CallerMock<>(projectService);
         sessionInfo = new SessionInfoMock();
 
         selectedOrganizationalUnit = mock(OrganizationalUnit.class);
@@ -129,7 +165,11 @@ public class AddProjectPopUpPresenterTest {
                                                      conflictingRepositoriesPopup,
                                                      validationServiceCaller,
                                                      errorPopup,
-                                                     translationService));
+                                                     translationService,
+                                                     projectServiceCaller,
+                                                     logger,
+                                                     archetypePreferences,
+                                                     spaceScopedResolutionStrategySupplier));
 
         doReturn("baseUrl").when(presenter).getBaseURL();
 
@@ -145,6 +185,8 @@ public class AddProjectPopUpPresenterTest {
         doReturn(true).when(validationService).validateArtifactId(any());
         doReturn(true).when(validationService).validateGAVVersion(any());
 
+        doReturn(mock(WorkspaceProject.class)).when(libraryService).createProject(any(), any(), any(), Mockito.<String> any());
+
         presenter.setup();
     }
 
@@ -158,7 +200,7 @@ public class AddProjectPopUpPresenterTest {
     public void cancelTest() {
         presenter.cancel();
 
-        view.hide();
+        verify(view).hide();
     }
 
     @Test
@@ -176,7 +218,8 @@ public class AddProjectPopUpPresenterTest {
         verify(view).setAddButtonEnabled(false);
         verify(libraryService).createProject(eq(organizationalUnit),
                                              pomArgumentCaptor.capture(),
-                                             eq(DeploymentMode.VALIDATED));
+                                             eq(DeploymentMode.VALIDATED),
+                                             Mockito.<String> any());
         verify(view).setAddButtonEnabled(true);
     }
 
@@ -199,7 +242,8 @@ public class AddProjectPopUpPresenterTest {
         verify(view).setAddButtonEnabled(false);
         verify(libraryService).createProject(eq(organizationalUnit),
                                              pomArgumentCaptor.capture(),
-                                             eq(DeploymentMode.VALIDATED));
+                                             eq(DeploymentMode.VALIDATED),
+                                             Mockito.<String> any());
         verify(view).setAddButtonEnabled(true);
 
         final POM pom = pomArgumentCaptor.getValue();
@@ -235,7 +279,8 @@ public class AddProjectPopUpPresenterTest {
         verify(view).setAddButtonEnabled(false);
         verify(libraryService).createProject(eq(organizationalUnit),
                                              pomArgumentCaptor.capture(),
-                                             eq(DeploymentMode.VALIDATED));
+                                             eq(DeploymentMode.VALIDATED),
+                                             Mockito.<String> any());
         verify(view).setAddButtonEnabled(true);
         
         final POM pom = pomArgumentCaptor.getValue();
@@ -260,12 +305,26 @@ public class AddProjectPopUpPresenterTest {
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(view).setAddButtonEnabled(true);
-        verify(newProjectEvent).fire(any(NewProjectEvent.class));
         verify(view).hide();
         verify(notificationEvent).fire(any(NotificationEvent.class));
-        verify(libraryPlaces).goToProject(any(WorkspaceProject.class));
+        verify(libraryPlaces, never()).goToProject(any(WorkspaceProject.class));
+    }
+
+    @Test
+    public void createProjectFromTemplateTest() {
+        doReturn("test").when(view).getName();
+        doReturn("description").when(view).getDescription();
+        doReturn(true).when(view).isBasedOnTemplate();
+        doReturn("template").when(view).getSelectedTemplate();
+
+        presenter.add();
+
+        verify(libraryService).createProject(any(),
+                                             any(),
+                                             any(),
+                                             eq("template"));
     }
 
     @Test
@@ -275,20 +334,21 @@ public class AddProjectPopUpPresenterTest {
 
         doThrow(new FileAlreadyExistsException()).when(libraryService).createProject(any(),
                                                                                      any(),
-                                                                                     any());
+                                                                                     any(),
+                                                                                     Mockito.<String> any());
         doAnswer(invocationOnMock -> ((Throwable) invocationOnMock.getArguments()[0]).getCause() instanceof FileAlreadyExistsException)
                 .when(presenter).isDuplicatedProjectName(any());
 
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -300,7 +360,7 @@ public class AddProjectPopUpPresenterTest {
         doReturn("description").when(view).getDescription();
 
         doThrow(new IllegalStateException("New repository should always have a branch."))
-                .when(libraryService).createProject(any(), any(), any());
+                .when(libraryService).createProject(any(), any(), any(), Mockito.<String> any());
 
         presenter.add();
 
@@ -310,9 +370,9 @@ public class AddProjectPopUpPresenterTest {
 
         verify(busyIndicatorView).hideBusyIndicator();
 
-        verify(errorPopup).showError(anyString(), anyString());
+        verify(errorPopup).showError(Mockito.<String> any(), Mockito.<String> any());
 
-        verify(translationService).format(anyString(), anyString());
+        verify(translationService).format(Mockito.<String> any(), Mockito.<String> any());
     }
 
     @Test
@@ -327,13 +387,13 @@ public class AddProjectPopUpPresenterTest {
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -351,13 +411,13 @@ public class AddProjectPopUpPresenterTest {
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -375,13 +435,13 @@ public class AddProjectPopUpPresenterTest {
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -399,13 +459,13 @@ public class AddProjectPopUpPresenterTest {
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -425,13 +485,13 @@ public class AddProjectPopUpPresenterTest {
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -446,18 +506,18 @@ public class AddProjectPopUpPresenterTest {
         doReturn("version").when(view).getVersion();
         doReturn(true).when(view).isAdvancedOptionsSelected();
 
-        doReturn(false).when(validationService).validateGroupId(anyString());
+        doReturn(false).when(validationService).validateGroupId(Mockito.<String> any());
 
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -472,18 +532,18 @@ public class AddProjectPopUpPresenterTest {
         doReturn("version").when(view).getVersion();
         doReturn(true).when(view).isAdvancedOptionsSelected();
 
-        doReturn(false).when(validationService).validateArtifactId(anyString());
+        doReturn(false).when(validationService).validateArtifactId(Mockito.<String> any());
 
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -498,18 +558,18 @@ public class AddProjectPopUpPresenterTest {
         doReturn("version").when(view).getVersion();
         doReturn(true).when(view).isAdvancedOptionsSelected();
 
-        doReturn(false).when(validationService).validateGAVVersion(anyString());
+        doReturn(false).when(validationService).validateGAVVersion(Mockito.<String> any());
 
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(newProjectEvent,
                never()).fire(any(NewProjectEvent.class));
         verify(view).hideBusyIndicator();
         verify(view,
                never()).hide();
-        verify(view).showError(anyString());
+        verify(view).showError(Mockito.<String> any());
         verify(libraryPlaces,
                never()).goToProject(any(WorkspaceProject.class));
         verify(view).setAddButtonEnabled(true);
@@ -526,9 +586,53 @@ public class AddProjectPopUpPresenterTest {
         presenter.add();
 
         verify(view).setAddButtonEnabled(false);
-        verify(view).showBusyIndicator(anyString());
+        verify(view).showBusyIndicator(Mockito.<String> any());
         verify(view).setAddButtonEnabled(true);
-        verify(command).execute(any());
+        verify(command, never()).execute(any());
+    }
+
+    @Test
+    public void createProjectCallbackAfterProjectIndexedEventTest() {
+        final WorkspaceProject project = mock(WorkspaceProject.class);
+        final Path projectRootPath = mock(Path.class);
+        doReturn(projectRootPath).when(project).getRootPath();
+        doReturn(project).when(projectService).resolveProject(any(Path.class));
+        doReturn(project).when(libraryService).createProject(any(), any(), any(), Mockito.<String> any());
+        doReturn("test").when(view).getName();
+        doReturn("description").when(view).getDescription();
+
+        presenter.onProjectIndexingFinishedEvent(new IndexingFinishedEvent("kClusterId",
+                                                                           projectRootPath));
+        presenter.add();
+
+        verify(view).setAddButtonEnabled(false);
+        verify(view).showBusyIndicator(Mockito.<String> any());
+        verify(view).setAddButtonEnabled(true);
+        verify(view).hide();
+        verify(notificationEvent).fire(any(NotificationEvent.class));
+        verify(libraryPlaces).goToProject(project);
+    }
+
+    @Test
+    public void createProjectCallbackBeforeProjectIndexedEventTest() {
+        final WorkspaceProject project = mock(WorkspaceProject.class);
+        final Path projectRootPath = mock(Path.class);
+        doReturn(projectRootPath).when(project).getRootPath();
+        doReturn(project).when(projectService).resolveProject(any(Path.class));
+        doReturn(project).when(libraryService).createProject(any(), any(), any(), Mockito.<String> any());
+        doReturn("test").when(view).getName();
+        doReturn("description").when(view).getDescription();
+
+        presenter.add();
+        presenter.onProjectIndexingFinishedEvent(new IndexingFinishedEvent("kClusterId",
+                                                                           projectRootPath));
+
+        verify(view).setAddButtonEnabled(false);
+        verify(view).showBusyIndicator(Mockito.<String> any());
+        verify(view).setAddButtonEnabled(true);
+        verify(view).hide();
+        verify(notificationEvent).fire(any(NotificationEvent.class));
+        verify(libraryPlaces).goToProject(project);
     }
 
     @Test
@@ -576,4 +680,90 @@ public class AddProjectPopUpPresenterTest {
         verify(view, never()).setDescription(any());
         verify(view).setArtifactId("ProjectTest");
     }
+
+    @Test
+    public void testLoadTemplatesWhenAllAvailable() {
+        final ArchetypePreferences preferences = mock(ArchetypePreferences.class);
+
+        final Map<String, Boolean> archetypeSelectionMap = new HashMap<>();
+        archetypeSelectionMap.put("template1", true);
+        archetypeSelectionMap.put("template2", true);
+        archetypeSelectionMap.put("template3", true);
+
+        doReturn(archetypeSelectionMap).when(preferences).getArchetypeSelectionMap();
+        doReturn("template2").when(preferences).getDefaultSelection();
+
+        final List<String> templates = Arrays.asList("template1", "template2", "template3");
+
+        presenter.finishLoadTemplates(preferences);
+
+        verify(view).setTemplates(templates, 1);
+    }
+
+    @Test
+    public void testLoadTemplatesWhenSomeAvailable() {
+        final ArchetypePreferences preferences = mock(ArchetypePreferences.class);
+
+        final Map<String, Boolean> archetypeSelectionMap = new HashMap<>();
+        archetypeSelectionMap.put("template1", true);
+        archetypeSelectionMap.put("template2", true);
+        archetypeSelectionMap.put("template3", false);
+
+        doReturn(archetypeSelectionMap).when(preferences).getArchetypeSelectionMap();
+        doReturn("template2").when(preferences).getDefaultSelection();
+
+        final List<String> templates = Arrays.asList("template1", "template2");
+
+        presenter.finishLoadTemplates(preferences);
+
+        verify(view).setTemplates(templates, 1);
+    }
+
+    @Test
+    public void testLoadTemplatesWhenDefaultNotPresent() {
+        final ArchetypePreferences preferences = mock(ArchetypePreferences.class);
+
+        final Map<String, Boolean> archetypeSelectionMap = new HashMap<>();
+        archetypeSelectionMap.put("template1", true);
+        archetypeSelectionMap.put("template2", true);
+        archetypeSelectionMap.put("template3", false);
+
+        doReturn(archetypeSelectionMap).when(preferences).getArchetypeSelectionMap();
+        doReturn("template3").when(preferences).getDefaultSelection();
+
+        final List<String> templates = Arrays.asList("template1", "template2");
+
+        presenter.finishLoadTemplates(preferences);
+
+        verify(view).setTemplates(templates, 0);
+    }
+
+    @Test
+    public void testLoadTemplatesWhenEmpty() {
+        final ArchetypePreferences preferences = mock(ArchetypePreferences.class);
+        doReturn(Collections.emptyMap()).when(preferences).getArchetypeSelectionMap();
+
+        presenter.finishLoadTemplates(preferences);
+
+        verify(view).setTemplates(Collections.singletonList(
+                translationService.getTranslation(LibraryConstants.NoTemplatesAvailable)),
+                                  0);
+    }
+
+    @Test
+    public void testLoadTemplatesWhenNoOneAvailable() {
+        final ArchetypePreferences preferences = mock(ArchetypePreferences.class);
+        final Map<String, Boolean> archetypeSelectionMap = new HashMap<>();
+        archetypeSelectionMap.put("template1", false);
+        archetypeSelectionMap.put("template2", false);
+        archetypeSelectionMap.put("template3", false);
+
+        doReturn(archetypeSelectionMap).when(preferences).getArchetypeSelectionMap();
+
+        presenter.finishLoadTemplates(preferences);
+
+        verify(view).setTemplates(Collections.singletonList(
+                translationService.getTranslation(LibraryConstants.NoTemplatesAvailable)),
+                                  0);
+    }
 }
