@@ -52,7 +52,7 @@ import org.kie.workbench.common.screens.server.management.service.SpecManagement
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.mockito.Spy;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.slf4j.Logger;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
@@ -61,7 +61,7 @@ import org.uberfire.workbench.events.NotificationEvent;
 import static org.junit.Assert.*;
 import static org.mockito.Mockito.*;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class ServerManagementBrowserPresenterTest {
 
     @Mock
@@ -235,25 +235,19 @@ public class ServerManagementBrowserPresenterTest {
 
     @Test
     public void testOnServerTemplateUpdated() {
-        final ServerInstanceKey serverInstanceKey = new ServerInstanceKey( "serverInstanceKeyId", "serverName", "serverInstanceId", "url" );
         final ServerTemplate serverTemplate = new ServerTemplate( "ServerTemplateId", "ServerTemplateName" );
-        serverTemplate.addServerInstance( serverInstanceKey );
-        when( serverTemplatePresenter.getCurrentServerTemplate() ).thenReturn( serverTemplate );
-        final ServerTemplateKey serverTemplateKey = new ServerTemplateKey( "ServerTemplateKeyId", "ServerTemplateKeyName" );
-        final List<ServerTemplateKey> serverTemplateKeys = Collections.singletonList( serverTemplateKey );
-        when( specManagementService.listServerTemplateKeys() ).thenReturn( new ServerTemplateKeyList(serverTemplateKeys) );
 
         presenter.onServerTemplateUpdated( new ServerTemplateUpdated( serverTemplate ) );
 
         final ArgumentCaptor<Collection> serverTemplateKeysCaptor = ArgumentCaptor.forClass( Collection.class );
-        verify( navigationPresenter ).setup( eq( serverTemplateKey ), serverTemplateKeysCaptor.capture() );
-        final Collection<ServerTemplateKey> serverTemplateKeysValue = serverTemplateKeysCaptor.getValue();
-        assertEquals( 1, serverTemplateKeysValue.size() );
-        assertTrue( serverTemplateKeysValue.contains( serverTemplateKey ) );
+        verify( navigationPresenter ).setup( eq( serverTemplate ), serverTemplateKeysCaptor.capture() );
+        final Collection<ServerTemplateKey> serverTemplateKeys = serverTemplateKeysCaptor.getValue();
+        assertEquals( 1, serverTemplateKeys.size() );
+        assertTrue( serverTemplateKeys.contains( serverTemplate ) );
 
         final ArgumentCaptor<ServerTemplateSelected> templateSelectedCaptor = ArgumentCaptor.forClass( ServerTemplateSelected.class );
         verify( serverTemplateSelectedEvent ).fire( templateSelectedCaptor.capture() );
-        assertEquals( serverTemplateKey, templateSelectedCaptor.getValue().getServerTemplateKey() );
+        assertEquals( serverTemplate, templateSelectedCaptor.getValue().getServerTemplateKey() );
     }
 
     @Test
