@@ -40,11 +40,6 @@ public interface StunnerTranslationService {
      */
     String getDefinitionSetDescription(String defSetId);
 
-    /**
-     * Retrieves the name for the given Property Set ID
-     */
-    String getPropertySetName(String propertySetId);
-
     /**
      * Retrieves the title for the given Definition ID
      */
@@ -60,15 +55,15 @@ public interface StunnerTranslationService {
      */
     String getPropertyCaption(String propId);
 
-    /**
-     * Retrieves the description for the given Property ID
-     */
-    String getPropertyDescription(String propId);
-
     /**
      * Returns the localized message for the given rule violation.
      */
     String getViolationMessage(RuleViolation ruleViolation);
 
     Optional<String> getDefinitionSetSvgNodeId(String defId);
+
+    /**
+     * Retrieves the name for the given element by ID
+     */
+    Optional<String> getElementName(String uuid);
 }
