@@ -30,16 +30,16 @@ import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.Mockito;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertNotEquals;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class AddCanvasConnectorCommandTest extends AbstractCanvasCommandTest {
 
     private static final String EDGE_ID = "e1";
@@ -87,13 +87,13 @@ public class AddCanvasConnectorCommandTest extends AbstractCanvasCommandTest {
                                   eq(candidate));
         verify(canvasHandler,
                times(1)).applyElementMutation(eq(candidate),
-                                              any(MutationContext.class));
+                                              Mockito.<MutationContext>any());
+        verify(canvasHandler,
+               times(1)).notifyCanvasElementUpdated(eq(source));
         verify(candidateShape,
                times(1)).applyConnections(eq(candidate),
                                           eq(sourceShapeView),
-                                          eq(null),
-                                          any(MutationContext.class));
-        verify(canvasHandler,
-               times(1)).notifyCanvasElementUpdated(eq(source));
+                                          Mockito.<ShapeView>any(),
+                                          Mockito.<MutationContext>any());
     }
 }
