@@ -17,6 +17,7 @@
 package org.kie.workbench.common.stunner.core.rule.handler.impl;
 
 import java.util.Optional;
+
 import javax.enterprise.context.ApplicationScoped;
 
 import org.kie.workbench.common.stunner.core.rule.RuleEvaluationHandler;
@@ -57,7 +58,7 @@ public class EdgeCardinalityEvaluationHandler implements RuleEvaluationHandler<E
         final DefaultRuleViolations results = new DefaultRuleViolations();
         final int minOccurrences = rule.getMinOccurrences();
         final int maxOccurrences = rule.getMaxOccurrences();
-        final int candidatesCount = context.getCandidateCount();
+        final int candidatesCount = context.getCurrentCount();
         final Optional<CardinalityContext.Operation> operation = context.getOperation();
         final EdgeCardinalityContext.Direction direction = rule.getDirection();
         final Violation.Type type = operation
