@@ -36,9 +36,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleIn
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.HasProcessData;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
+import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanContain;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanDock;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
@@ -50,7 +49,7 @@ import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.pr
 @Bindable
 @CanContain(roles = {"all"})
 @CanDock(roles = {"IntermediateEventOnSubprocessBoundary"})
-@Definition(graphFactory = NodeFactory.class)
+@Definition
 @Morph(base = BaseSubprocess.class)
 
 @FormDefinition(
@@ -60,14 +59,14 @@ import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.pr
 )
 public class MultipleInstanceSubprocess extends BaseSubprocess implements HasProcessData<ProcessData> {
 
-    @PropertySet
+    @Property
     @FormField(
             afterElement = "general"
     )
     @Valid
     protected MultipleInstanceSubprocessTaskExecutionSet executionSet;
 
-    @PropertySet
+    @Property
     @FormField(
             afterElement = "executionSet"
     )
