@@ -34,7 +34,7 @@ import org.kie.workbench.common.stunner.core.util.StringUtils;
 import org.kie.workbench.common.stunner.core.validation.DomainViolation;
 import org.kie.workbench.common.stunner.core.validation.Violation;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
@@ -92,8 +92,6 @@ public class BPMNValidatorImplTest {
 
     @Test
     public void validateWithException() {
-        when(diagram.getMetadata()).thenThrow(new RuntimeException());
-
         final Collection<BPMNViolation> violations = bpmnValidador.validate(null, PROCESS_UUID);
         assertProcessException(violations);
     }
