@@ -166,12 +166,12 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
     }
 
     String getVariableCountsString(final String datainput,
-                                             final String datainputset,
-                                             final String dataoutput,
-                                             final String dataoutputset,
-                                             final String processvars,
-                                             final String assignments,
-                                             final String disallowedpropertynames) {
+                                   final String datainputset,
+                                   final String dataoutput,
+                                   final String dataoutputset,
+                                   final String processvars,
+                                   final String assignments,
+                                   final String disallowedpropertynames) {
         String inputvars = null;
         if (datainput != null) {
             inputvars = datainput;
@@ -210,7 +210,6 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
                 DataObjectUtils.findDataObjects(canvasSessionManager.getCurrentSession(), graphUtils, getSelectedElement(), getParentIds()).stream()
                         .map(AssignmentsEditorWidget::dataObjectToProcessVariableFormat)
                         .collect(Collectors.joining(","));
-
         if (!dataObjects.isEmpty()) {
             sb.append(dataObjects);
         }
@@ -251,8 +250,8 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
         return parentIds;
     }
 
-    private static String dataObjectToProcessVariableFormat(DataObject dataObject) {
-        return dataObject.getName().getValue() + ":" + dataObject.getType().getValue().getType();
+    protected static String dataObjectToProcessVariableFormat(DataObject dataObject) {
+        return dataObject.getName().getValue().replace("\n", "") + ":" + dataObject.getType().getValue().getType();
     }
 
     protected String getSelectedElementUUID(ClientSession clientSession) {
@@ -312,7 +311,7 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
                     return null;
                 })
                 .catch_(exception -> {
-                    notification.fire(new NotificationEvent(StunnerFormsClientFieldsConstants.INSTANCE.Error_retrieving_datatypes(),
+                    notification.fire(new NotificationEvent(StunnerFormsClientFieldsConstants.CONSTANTS.Error_retrieving_datatypes(),
                                                             NotificationEvent.NotificationType.ERROR));
                     showDataIOEditor(simpleDataTypes);
                     return null;
@@ -324,6 +323,20 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
         return diagram.getMetadata().getPath();
     }
 
+    private Set<String> getSetDataTypes() {
+
+        Map<String, String> assignmentsProperties = AssignmentParser.parseAssignmentsInfo(assignmentsInfo);
+
+        String datainputset = assignmentsProperties.get(AssignmentParser.DATAINPUTSET);
+        String dataoutputset = assignmentsProperties.get(AssignmentParser.DATAOUTPUTSET);
+
+        Set<String> set = new HashSet<>();
+        set.addAll(StringUtils.getSetDataTypes(datainputset));
+        set.addAll(StringUtils.getSetDataTypes(dataoutputset));
+
+        return set;
+    }
+
     public void showDataIOEditor(final String datatypes) {
         String taskName = getTaskName();
         String processvars = getProcessVariables();
@@ -362,12 +375,22 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
                                                hasOutputVars,
                                                isSingleOutputVar);
 
-        ActivityDataIOEditor.GetDataCallback callback = assignmentDataJson -> {
-            AssignmentData assignmentData1 = Marshalling.fromJSON(assignmentDataJson,
-                                                                  AssignmentData.class);
-            String assignmentsInfoString = createAssignmentsInfoString(assignmentData1);
-            setValue(assignmentsInfoString,
-                     true);
+        ActivityDataIOEditor.GetDataCallback callback = new ActivityDataIOEditor.GetDataCallback() {
+            @Override
+            public void getData(String assignmentDataJson) {
+                AssignmentData assignmentData1 = Marshalling.fromJSON(assignmentDataJson,
+                                                                      AssignmentData.class);
+                String assignmentsInfoString = createAssignmentsInfoString(assignmentData1);
+                setValue(assignmentsInfoString,
+                         true);
+            }
+
+            @Override
+            public void addDataType(String dataType, String oldType) {
+                if (dataType != null && !dataType.isEmpty()) {
+                    clientDataTypesService.add(dataType, oldType);
+                }
+            }
         };
 
         activityDataIOEditor.setCallback(callback);
@@ -405,11 +428,22 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
     }
 
     protected String formatDataTypes(final List<String> dataTypes) {
+
+        Set<String> set = getSetDataTypes();
         StringBuilder sb = new StringBuilder();
         if (dataTypes != null && !dataTypes.isEmpty()) {
             List<String> formattedDataTypes = new ArrayList<>(dataTypes.size());
             for (String dataType : dataTypes) {
-                formattedDataTypes.add(StringUtils.createDataTypeDisplayName(dataType) + ":" + dataType);
+                boolean isAsset = false;
+
+                if (dataType.contains("Asset-")) {
+                    dataType = dataType.substring(6);
+                    isAsset = true;
+                }
+                if (!isAsset && set.contains(dataType)) {
+                    continue;
+                }
+                formattedDataTypes.add(dataType + ":" + dataType);
             }
             Collections.sort(formattedDataTypes);
             for (String formattedDataType : formattedDataTypes) {
@@ -446,4 +480,4 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
                 .append('|').append(assignmentData.getAssignmentsString());
         return sb.toString();
     }
-}
+}
\ No newline at end of file
