@@ -145,6 +145,7 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
         dataTypeListBoxValues = new ListBoxValues(VariableListItemWidgetView.CUSTOM_PROMPT,
                                                   "Edit" + " ",
                                                   dataTypesTester());
+
         dataTypeListBoxValues.addValues(dataTypeDisplayNames);
         view.setVariablesDataTypes(dataTypeListBoxValues);
     }
@@ -294,6 +295,11 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
         return lastOverlayOpened;
     }
 
+    @Override
+    public void addDataType(String dataType, String oldType) {
+        view.addDataType(dataType, oldType);
+    }
+
     public void closeLastOverlay() {
         if (lastOverlayOpened != null) {
             lastOverlayOpened.click();
