@@ -71,9 +71,9 @@ public interface BPMNImageResources extends ClientBundleWithLookup {
     @DataResource.MimeType("image/svg+xml")
     DataResource categoryServiceTasks();
 
-    @ClientBundle.Source("images/categories/text-annotation.svg")
+    @ClientBundle.Source("images/categories/artifacts.svg")
     @DataResource.MimeType("image/svg+xml")
-    DataResource categoryTextAnnotation();
+    DataResource categoryArtifacts();
 
     // **** Icons Sprite ****
 
@@ -97,7 +97,7 @@ public interface BPMNImageResources extends ClientBundleWithLookup {
     @ClientBundle.Source("images/icons/task/task-business-rule.png")
     ImageResource taskBusinessRule();
 
-    @ClientBundle.Source("images/icons/default-service-node-icon.png")
+    @ClientBundle.Source("images/icons/defaultservicenodeicon.png")
     ImageResource serviceNodeIcon();
 
     //This is a hack for OOME related to SVG, or image/svg+xml;base64 URLs
